# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import Component, IonPolarity, IRange, MSScanType, RangeCollection
from .AgileIntegrator import Peak
from .Quantitative import (
    ChromatographyType,
    IFeature,
    ITimeToMassConversion,
    ScanRecord,
)

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.FD

class Apex:  # Class
    @overload
    def __init__(
        self,
        xApexIndex: int,
        yApexIndex: int,
        xAxis: Agilent.MassSpectrometry.DataAnalysis.FD.IAxisGrid,
        y: List[float],
    ) -> None: ...
    @overload
    def __init__(
        self,
        xApexIndex: int,
        yApexIndex: int,
        xAxis: Agilent.MassSpectrometry.DataAnalysis.FD.IAxisGrid,
        y: System.Collections.Generic.List[float],
    ) -> None: ...
    @overload
    def __init__(
        self,
        xApexIndex: int,
        yApexIndex: int,
        xAxis: Agilent.MassSpectrometry.DataAnalysis.FD.IAxisGrid,
        y1: int,
        y2: int,
        y3: int,
    ) -> None: ...

    Index: int  # readonly
    InterpolatedX: float  # readonly
    InterpolatedY: float  # readonly
    IsInterpolated: bool  # readonly
    X: float  # readonly
    Y: float  # readonly

    @staticmethod
    def DoParabolicFit(
        x1: float,
        x2: float,
        x3: float,
        y1: float,
        y2: float,
        y3: float,
        a0: float,
        a1: float,
        a2: float,
    ) -> bool: ...

class CentroidType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    GC_2GHzData: Agilent.MassSpectrometry.DataAnalysis.FD.CentroidType = (
        ...
    )  # static # readonly
    GC_4GHzData: Agilent.MassSpectrometry.DataAnalysis.FD.CentroidType = (
        ...
    )  # static # readonly
    LC_2GHzData: Agilent.MassSpectrometry.DataAnalysis.FD.CentroidType = (
        ...
    )  # static # readonly
    LC_4GHzData: Agilent.MassSpectrometry.DataAnalysis.FD.CentroidType = (
        ...
    )  # static # readonly

class DoubleRange:  # Class
    def __init__(self, min: float, max: float) -> None: ...

    Center: float  # readonly
    Max: float  # readonly
    Min: float  # readonly
    Width: float  # readonly

    def Overlaps(
        self, range: Agilent.MassSpectrometry.DataAnalysis.FD.DoubleRange
    ) -> bool: ...
    def Contains(self, value_: float) -> bool: ...

class Feature(IFeature):  # Class
    @overload
    def __init__(
        self, scanSpace: Agilent.MassSpectrometry.DataAnalysis.FD.IScanSpace
    ) -> None: ...
    @overload
    def __init__(
        self,
        ridge: Agilent.MassSpectrometry.DataAnalysis.FD.Ridge,
        peak: Peak,
        fd: Agilent.MassSpectrometry.DataAnalysis.FD.FeatureDetector,
    ) -> None: ...
    @overload
    def __init__(
        self,
        ridge: Agilent.MassSpectrometry.DataAnalysis.FD.Ridge,
        peakFinderRangeStartOffset: int,
        peak: Peak,
        fd: Agilent.MassSpectrometry.DataAnalysis.FD.FeatureDetector,
    ) -> None: ...
    @overload
    def __init__(
        self,
        ridge: Agilent.MassSpectrometry.DataAnalysis.FD.Ridge,
        peakFinderRangeStartOffset: int,
        peak: Peak,
        fd: Agilent.MassSpectrometry.DataAnalysis.FD.FeatureDetector,
        manuallyIntegratedFeature: bool,
    ) -> None: ...

    Abundance: List[float]  # readonly
    ApexInterpolatedMz: float  # readonly
    ApexOffset: int  # readonly
    ApexPointIndex: int  # readonly
    ApexScanIndex: int  # readonly
    Area: float  # readonly
    AssignedFlightTime: float  # readonly
    AssignedMz: float  # readonly
    AssignedRT: float  # readonly
    AssignedScanAxisLocation: float  # readonly
    BaselineEnd: float  # readonly
    BaselineSlope: float  # readonly
    BaselineStart: float  # readonly
    BaselineYIntercept: float  # readonly
    CentroidMz: float  # readonly
    EndX: float  # readonly
    FWHM: float  # readonly
    FWHMPoints: float  # readonly
    FeatureID: int  # readonly
    FirstSaturatedScanIndex: int  # readonly
    FirstScanIndex: int  # readonly
    FlightTimeVariation: float  # readonly
    HasUnsaturatedPoints: bool  # readonly
    Height: float  # readonly
    InterpolatedApexAbundance: float  # readonly
    IsRestored: bool  # readonly
    IsSaturated: bool  # readonly
    LastSaturatedScanIndex: int  # readonly
    LastScanIndex: int  # readonly
    LeftBaselineEnd: float  # readonly
    LeftBaselineStart: float  # readonly
    Length: int  # readonly
    Noise: float  # readonly
    RestoredAbundance: List[float]  # readonly
    RestoredArea: float  # readonly
    RestoredHeight: float  # readonly
    RidgeID: int  # readonly
    RightBaselineEnd: float  # readonly
    RightBaselineStart: float  # readonly
    SaturatedRegionCount: int  # readonly
    SaturatedScanCount: int  # readonly
    SaturationRecoveryStatus: (
        Agilent.MassSpectrometry.DataAnalysis.FD.SaturatedFeatureRecoveryStatus
    )  # readonly
    ScanAxisPeakLocations: List[float]  # readonly
    ScanSpace: Agilent.MassSpectrometry.DataAnalysis.FD.IScanSpace  # readonly
    SignalToNoise: float  # readonly
    StartX: float  # readonly
    Symmetry: float  # readonly

    def Read(self, br: System.IO.BinaryReader, version: int) -> None: ...
    @overload
    def FitTo(
        self,
        f: Agilent.MassSpectrometry.DataAnalysis.FD.Feature,
        yOffset: float,
        yScale: float,
    ) -> None: ...
    @overload
    def FitTo(
        self,
        f: Agilent.MassSpectrometry.DataAnalysis.FD.Feature,
        yOffset: float,
        slope: float,
        yScale: float,
    ) -> None: ...
    def Write(self, bw: System.IO.BinaryWriter) -> None: ...
    def ApplyRecoveryResult(
        self,
        recovery: Agilent.MassSpectrometry.DataAnalysis.FD.SaturationRecoveryResult,
    ) -> None: ...
    def ApplyDynamicMassCalibration(self, recalibratedMz: float) -> None: ...
    def DebugWrite(self, sw: System.IO.StreamWriter) -> None: ...
    def RestoreDefaultMassCalibration(self) -> None: ...
    def RecoverSaturatedAbundance(
        self,
        template: Agilent.MassSpectrometry.DataAnalysis.FD.SaturationRecoveryTemplate,
        fd: Agilent.MassSpectrometry.DataAnalysis.FD.FeatureDetector,
    ) -> Agilent.MassSpectrometry.DataAnalysis.FD.SaturationRecoveryResult: ...

    # Nested Types

    class ApexComparer(
        System.Collections.Generic.IComparer[
            Agilent.MassSpectrometry.DataAnalysis.FD.Feature
        ]
    ):  # Class
        def __init__(self) -> None: ...
        def Compare(
            self,
            a: Agilent.MassSpectrometry.DataAnalysis.FD.Feature,
            b: Agilent.MassSpectrometry.DataAnalysis.FD.Feature,
        ) -> int: ...

    class FlightTimeComparer(
        System.Collections.Generic.IComparer[
            Agilent.MassSpectrometry.DataAnalysis.FD.Feature
        ]
    ):  # Class
        def __init__(self) -> None: ...
        def Compare(
            self,
            a: Agilent.MassSpectrometry.DataAnalysis.FD.Feature,
            b: Agilent.MassSpectrometry.DataAnalysis.FD.Feature,
        ) -> int: ...

    class MzComparer(
        System.Collections.Generic.IComparer[
            Agilent.MassSpectrometry.DataAnalysis.FD.Feature
        ]
    ):  # Class
        def __init__(self) -> None: ...
        def Compare(
            self,
            a: Agilent.MassSpectrometry.DataAnalysis.FD.Feature,
            b: Agilent.MassSpectrometry.DataAnalysis.FD.Feature,
        ) -> int: ...

    class RTComparer(
        System.Collections.Generic.IComparer[
            Agilent.MassSpectrometry.DataAnalysis.FD.Feature
        ]
    ):  # Class
        def __init__(self) -> None: ...
        def Compare(
            self,
            a: Agilent.MassSpectrometry.DataAnalysis.FD.Feature,
            b: Agilent.MassSpectrometry.DataAnalysis.FD.Feature,
        ) -> int: ...

    class ReverseAbundanceComparer(
        System.Collections.Generic.IComparer[
            Agilent.MassSpectrometry.DataAnalysis.FD.Feature
        ]
    ):  # Class
        def __init__(self) -> None: ...
        def Compare(
            self,
            a: Agilent.MassSpectrometry.DataAnalysis.FD.Feature,
            b: Agilent.MassSpectrometry.DataAnalysis.FD.Feature,
        ) -> int: ...

    class ReverseHeightComparer(
        System.Collections.Generic.IComparer[
            Agilent.MassSpectrometry.DataAnalysis.FD.Feature
        ]
    ):  # Class
        def __init__(self) -> None: ...
        def Compare(
            self,
            a: Agilent.MassSpectrometry.DataAnalysis.FD.Feature,
            b: Agilent.MassSpectrometry.DataAnalysis.FD.Feature,
        ) -> int: ...

    class ReverseLengthComparer(
        System.Collections.Generic.IComparer[
            Agilent.MassSpectrometry.DataAnalysis.FD.Feature
        ]
    ):  # Class
        def __init__(self) -> None: ...
        def Compare(
            self,
            a: Agilent.MassSpectrometry.DataAnalysis.FD.Feature,
            b: Agilent.MassSpectrometry.DataAnalysis.FD.Feature,
        ) -> int: ...

    class ReverseSaturatedScanCountComparer(
        System.Collections.Generic.IComparer[
            Agilent.MassSpectrometry.DataAnalysis.FD.Feature
        ]
    ):  # Class
        def __init__(self) -> None: ...
        def Compare(
            self,
            a: Agilent.MassSpectrometry.DataAnalysis.FD.Feature,
            b: Agilent.MassSpectrometry.DataAnalysis.FD.Feature,
        ) -> int: ...

class FeatureDetectionCompleted(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self, sender: Any, callback: System.AsyncCallback, object: Any
    ) -> System.IAsyncResult: ...
    def Invoke(self, sender: Any) -> None: ...

class FeatureDetectionParams:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, xmlFilePath: str) -> None: ...
    @overload
    def __init__(
        self, other: Agilent.MassSpectrometry.DataAnalysis.FD.FeatureDetectionParams
    ) -> None: ...

    PARAMETER_FILE: str = ...  # static # readonly

    ApplyRingFilter: bool
    EnablePhase1Recovery: bool
    EnablePhase2Recovery: bool
    FeatureSmoothingMaxSNR: float
    MassAssignmentType2GHz: Agilent.MassSpectrometry.DataAnalysis.FD.MassAssignmentType
    MassAssignmentType4GHz: Agilent.MassSpectrometry.DataAnalysis.FD.MassAssignmentType
    MinFeatureSNR: float
    MinFitPointsForX100Recovery: int
    MinFitPointsForX10Recovery: int
    MinLeftUnsaturatedPoints: int
    MinRightUnsaturatedPoints: int
    MinTotalUnsaturatedPoints: int
    RemovePrecursor: bool
    RemoveTrailer: bool
    SaturationRecovery: (
        Agilent.MassSpectrometry.DataAnalysis.FD.SaturationRecoveryTemplateType
    )
    SmoothingGaussianWidthInPoints: int
    SmoothingType: Agilent.MassSpectrometry.DataAnalysis.FD.SmoothingType

    def Equals(
        self, other: Agilent.MassSpectrometry.DataAnalysis.FD.FeatureDetectionParams
    ) -> bool: ...
    def Clone(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.FD.FeatureDetectionParams: ...

class FeatureDetectionStarted(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self, sender: Any, callback: System.AsyncCallback, object: Any
    ) -> System.IAsyncResult: ...
    def Invoke(self, sender: Any) -> None: ...

class FeatureDetector:  # Class
    def __init__(
        self,
        scanSpace: Agilent.MassSpectrometry.DataAnalysis.FD.IScanSpace,
        spectrumDataAccess: Agilent.MassSpectrometry.DataAnalysis.FD.SpectrumDataAccess,
        fdParams: Agilent.MassSpectrometry.DataAnalysis.FD.FeatureDetectionParams,
    ) -> None: ...

    ScanSpace: Agilent.MassSpectrometry.DataAnalysis.FD.IScanSpace  # readonly
    UseComponentBasedSaturationRecovery: bool  # readonly

    def GetMassCal(self, scanIndex: int) -> ITimeToMassConversion: ...
    def RecoverSaturatedFeatures(
        self,
        featureSet: Agilent.MassSpectrometry.DataAnalysis.FD.IFeatureSet,
        components: System.Collections.Generic.List[Component],
    ) -> None: ...
    def ApplyRingFilter(
        self,
        detectedFeatures: System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.FD.Feature
        ],
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.Feature
    ]: ...
    def DetectFeaturesInRidges(
        self,
        ridgeSet: Agilent.MassSpectrometry.DataAnalysis.FD.IRidgeSet,
        featureSet: Agilent.MassSpectrometry.DataAnalysis.FD.IFeatureSet,
    ) -> None: ...

class GaussianSmoothingKernel:  # Class
    @overload
    def __init__(self, widthInPoints: int) -> None: ...
    @overload
    def __init__(self, sigma: float) -> None: ...
    @overload
    def __init__(self, sigma: float, npts: int) -> None: ...
    def Smooth(self, data: List[float]) -> List[float]: ...

class IAxisGrid(object):  # Interface
    PointCount: int  # readonly

    def GetIndexOfNearestPointAbove(self, value_: float) -> int: ...
    def GetPointByIndex(self, index: int) -> float: ...
    def GetIndexOfNearestPointBelow(self, value_: float) -> int: ...
    def GetIndexOfNearestPoint(self, value_: float) -> int: ...

class IFeatureSet(
    Agilent.MassSpectrometry.DataAnalysis.FD.IFeatureSetQuery
):  # Interface
    FeatureDetectionParams: (
        Agilent.MassSpectrometry.DataAnalysis.FD.FeatureDetectionParams
    )  # readonly
    ScanSpace: Agilent.MassSpectrometry.DataAnalysis.FD.IScanSpace  # readonly

    def Add(self, f: Agilent.MassSpectrometry.DataAnalysis.FD.Feature) -> None: ...

class IFeatureSetQuery(object):  # Interface
    Count: int  # readonly
    SaturatedCount: int  # readonly

    @overload
    def GetFeatures(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.Feature
    ]: ...
    @overload
    def GetFeatures(
        self, minScanIndex: int, maxScanIndex: int
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.Feature
    ]: ...
    @overload
    def GetFeatures(
        self, rtStart: float, rtEnd: float
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.Feature
    ]: ...
    def GetCoelutingFeatures(
        self, apexScanIndex: int
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.Feature
    ]: ...
    @overload
    def GetFeaturesInRange(
        self, minScanIndex: int, maxScanIndex: int, mzLow: float, mzHigh: float
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.Feature
    ]: ...
    @overload
    def GetFeaturesInRange(
        self, rtStart: float, rtEnd: float, mzLow: float, mzHigh: float
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.Feature
    ]: ...
    def GetFeatureByID(
        self, featureID: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.FD.Feature: ...
    def GetFeaturesInFlightTimeRange(
        self, rtStart: float, rtEnd: float, lowFlightTime: float, highFlightTime: float
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.Feature
    ]: ...
    def GetFeaturesInMzRange(
        self, mzLow: float, mzHigh: float
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.Feature
    ]: ...

class IProcessedSpectrum(object):  # Interface
    ApexList: List[int]  # readonly
    ApexMap: List[int]  # readonly
    FilteredApexList: System.Collections.Generic.List[int]  # readonly
    IsSaturated: bool  # readonly
    NoiseStatistics: (
        Agilent.MassSpectrometry.DataAnalysis.FD.ISpectrumNoiseStatistics
    )  # readonly
    PartialSaturationThreshold: int  # readonly
    PeakFinder: (
        Agilent.MassSpectrometry.DataAnalysis.FD.IProfileSpectrumPeakFinder
    )  # readonly
    ProfileSpectrum: (
        Agilent.MassSpectrometry.DataAnalysis.FD.IProfileSpectrum
    )  # readonly
    SaturatedRanges: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.SaturatedRange
    ]  # readonly

    def IsApexAbovePartialSaturatedThreshold(self, apexIndex: int) -> bool: ...
    def FindStartOfPeak(self, apexIndex: int) -> int: ...
    def SortApexListByAbundance(self) -> List[int]: ...

class IProfileSpectrum(System.IDisposable):  # Interface
    CycleNumber: int  # readonly
    IntAbundanceArray: List[int]  # readonly
    IsTimeOfFlightSpectrum: bool  # readonly
    PointCount: int  # readonly
    SaturationLimit: int  # readonly
    ScanID: int  # readonly
    ScanIndex: int  # readonly
    ScanSpace: Agilent.MassSpectrometry.DataAnalysis.FD.IScanSpace  # readonly
    TimeToMassConversion: ITimeToMassConversion  # readonly

    def ReleaseSpectrumAbundanceValues(self) -> None: ...

class IProfileSpectrumPeakFinder(object):  # Interface
    def GetSaturatedRanges(
        self,
        abundance: List[int],
        saturationThreshold: int,
        fullSaturationThreshold: int,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.SaturatedRange
    ]: ...
    @overload
    def GetApexList(
        self, spectrum: Agilent.MassSpectrometry.DataAnalysis.FD.IProfileSpectrum
    ) -> List[int]: ...
    @overload
    def GetApexList(
        self,
        spectrum: Agilent.MassSpectrometry.DataAnalysis.FD.IProfileSpectrum,
        threshold: int,
    ) -> List[int]: ...
    @overload
    def GetApexList(self, abundance: List[int]) -> List[int]: ...
    @overload
    def GetApexList(self, abundance: List[int], threshold: int) -> List[int]: ...

class IRidgeSet(object):  # Interface
    Count: int  # readonly
    NoiseFactor2: float  # readonly
    RidgeDetectionParams: (
        Agilent.MassSpectrometry.DataAnalysis.FD.RidgeDetectionParams
    )  # readonly
    RidgeList: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.Ridge
    ]  # readonly
    SaturationLimit: float  # readonly
    ScanSpace: Agilent.MassSpectrometry.DataAnalysis.FD.IScanSpace  # readonly

    @overload
    def GetRidgesInRange(
        self, rtMin: float, rtMax: float, mzMin: float, mzMax: float
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.Ridge
    ]: ...
    @overload
    def GetRidgesInRange(
        self, minScanIndex: int, maxScanIndex: int, mzMin: float, mzMax: float
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.Ridge
    ]: ...
    def GetRidgeByID(
        self, ridgeId: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.FD.Ridge: ...

class ISampleFeatures(object):  # Interface
    ScanConditionCount: int  # readonly
    ScanConditionList: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.ScanConditions
    ]  # readonly

    def GetFeatureSet(
        self, scanConditions: Agilent.MassSpectrometry.DataAnalysis.FD.ScanConditions
    ) -> Agilent.MassSpectrometry.DataAnalysis.FD.IFeatureSet: ...
    def GetScanSpace(
        self, scanConditions: Agilent.MassSpectrometry.DataAnalysis.FD.ScanConditions
    ) -> Agilent.MassSpectrometry.DataAnalysis.FD.IScanSpace: ...
    def CreateFeatureSet(
        self,
        scanSpace: Agilent.MassSpectrometry.DataAnalysis.FD.IScanSpace,
        fdParams: Agilent.MassSpectrometry.DataAnalysis.FD.FeatureDetectionParams,
    ) -> Agilent.MassSpectrometry.DataAnalysis.FD.IFeatureSet: ...
    def GetFeatureSets(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.IFeatureSet
    ]: ...
    def AddFeatureSet(
        self,
        scanSpace: Agilent.MassSpectrometry.DataAnalysis.FD.IScanSpace,
        featureSet: Agilent.MassSpectrometry.DataAnalysis.FD.IFeatureSet,
    ) -> None: ...

class ISampleRidges(object):  # Interface
    ScanConditionCount: int  # readonly
    ScanConditionList: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.ScanConditions
    ]  # readonly

    def AddRidgeSet(
        self,
        scanSpace: Agilent.MassSpectrometry.DataAnalysis.FD.IScanSpace,
        ridgeSet: Agilent.MassSpectrometry.DataAnalysis.FD.IRidgeSet,
    ) -> None: ...
    def GetScanSpace(
        self, scanConditions: Agilent.MassSpectrometry.DataAnalysis.FD.ScanConditions
    ) -> Agilent.MassSpectrometry.DataAnalysis.FD.IScanSpace: ...
    def GetRidgeSets(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.IRidgeSet
    ]: ...
    def GetRidgeSet(
        self, scanConditions: Agilent.MassSpectrometry.DataAnalysis.FD.ScanConditions
    ) -> Agilent.MassSpectrometry.DataAnalysis.FD.IRidgeSet: ...
    def AddDetectedRidgeSet(
        self, rd: Agilent.MassSpectrometry.DataAnalysis.FD.RidgeDetector
    ) -> None: ...

class IScanSpace(object):  # Interface
    IsOpen: bool  # readonly
    RTAxis: Agilent.MassSpectrometry.DataAnalysis.FD.RTAxis  # readonly
    ScanAxis: Agilent.MassSpectrometry.DataAnalysis.FD.ScanAxis  # readonly
    ScanConditions: Agilent.MassSpectrometry.DataAnalysis.FD.ScanConditions  # readonly

class ISpectrumNoiseStatistics(object):  # Interface
    NoiseBaseline: int  # readonly
    NoiseDeviation: int  # readonly
    NoiseMultiplier: int
    NoiseSignalThreshold: int  # readonly

class IntRange:  # Class
    def __init__(self, min: int, max: int) -> None: ...

    Max: int  # readonly
    Min: int  # readonly
    NumberOfPoints: int  # readonly

    @overload
    def Overlaps(
        self, range: Agilent.MassSpectrometry.DataAnalysis.FD.IntRange
    ) -> bool: ...
    @overload
    def Overlaps(self, min: int, max: int) -> bool: ...
    def Contains(self, value_: int) -> bool: ...
    @overload
    def GetOverlap(
        self, range: Agilent.MassSpectrometry.DataAnalysis.FD.IntRange
    ) -> Agilent.MassSpectrometry.DataAnalysis.FD.IntRange: ...
    @overload
    def GetOverlap(
        self, start: int, end: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.FD.IntRange: ...

class InterferenceDetector:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def ComputeFlightTimeVariation(
        f: Agilent.MassSpectrometry.DataAnalysis.FD.Feature,
    ) -> float: ...

class MassAssignmentType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    ApexInterpolated: Agilent.MassSpectrometry.DataAnalysis.FD.MassAssignmentType = (
        ...
    )  # static # readonly
    Centroid: Agilent.MassSpectrometry.DataAnalysis.FD.MassAssignmentType = (
        ...
    )  # static # readonly
    CentroidBiasCorrected: (
        Agilent.MassSpectrometry.DataAnalysis.FD.MassAssignmentType
    ) = ...  # static # readonly
    MzDependentCentroidBiasCorrected: (
        Agilent.MassSpectrometry.DataAnalysis.FD.MassAssignmentType
    ) = ...  # static # readonly

class ProcessedSpectrum(
    Agilent.MassSpectrometry.DataAnalysis.FD.IProcessedSpectrum
):  # Class
    def __init__(
        self,
        spectrum: Agilent.MassSpectrometry.DataAnalysis.FD.IProfileSpectrum,
        peakFinder: Agilent.MassSpectrometry.DataAnalysis.FD.IProfileSpectrumPeakFinder,
        chromType: ChromatographyType,
    ) -> None: ...
    @staticmethod
    def FilterSortedApexList(
        abundance: List[int], apexList: List[int], abundanceThreshold: int
    ) -> System.Collections.Generic.List[int]: ...
    def FilterApexListBySpacing(
        self,
        pointCount: int,
        apexList: System.Collections.Generic.List[int],
        minApexSpacing: int,
        maxAbundance: int,
    ) -> System.Collections.Generic.List[int]: ...
    @staticmethod
    def FilterApexList(
        abundance: List[int], apexList: List[int], abundanceThreshold: int
    ) -> System.Collections.Generic.List[int]: ...

class ProfileSpectrum(
    Agilent.MassSpectrometry.DataAnalysis.FD.IProfileSpectrum, System.IDisposable
):  # Class
    @overload
    def __init__(self, scanRecord: ScanRecord) -> None: ...
    @overload
    def __init__(
        self, scanRecord: ScanRecord, timeToMass: ITimeToMassConversion
    ) -> None: ...
    @overload
    def __init__(
        self,
        scanRecord: ScanRecord,
        useRunTimeMassCal: bool,
        timeToMass: ITimeToMassConversion,
    ) -> None: ...

    CycleNumber: int  # readonly
    IntAbundanceArray: List[int]  # readonly
    IsTimeOfFlightSpectrum: bool  # readonly
    PointCount: int  # readonly
    SaturationLimit: int  # readonly
    ScanID: int  # readonly
    ScanIndex: int  # readonly
    ScanRecord: ScanRecord  # readonly
    ScanSpace: Agilent.MassSpectrometry.DataAnalysis.FD.IScanSpace  # readonly
    TimeToMassConversion: ITimeToMassConversion  # readonly

    def ReleaseSpectrumAbundanceValues(self) -> None: ...
    def Dispose(self) -> None: ...

class ProfileSpectrumPeakFinder(
    Agilent.MassSpectrometry.DataAnalysis.FD.IProfileSpectrumPeakFinder
):  # Class
    def __init__(self) -> None: ...
    def GetSaturatedRanges(
        self,
        abundance: List[int],
        saturationThreshold: int,
        fullSaturationThreshold: int,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.SaturatedRange
    ]: ...
    def GetApexSpacingHistogram(self, apexList: List[int]) -> List[int]: ...
    @overload
    def GetApexList(
        self, spectrum: Agilent.MassSpectrometry.DataAnalysis.FD.IProfileSpectrum
    ) -> List[int]: ...
    @overload
    def GetApexList(
        self,
        spectrum: Agilent.MassSpectrometry.DataAnalysis.FD.IProfileSpectrum,
        threshold: int,
    ) -> List[int]: ...
    @overload
    def GetApexList(self, abundance: List[int]) -> List[int]: ...
    @overload
    def GetApexList(self, abundance: List[int], noiseThreshold: int) -> List[int]: ...

class RTAxis(Agilent.MassSpectrometry.DataAnalysis.FD.IAxisGrid):  # Class
    @overload
    def __init__(
        self,
        scanIDs: System.Collections.Generic.List[int],
        cycleNumbers: System.Collections.Generic.List[int],
        scanTimes: System.Collections.Generic.List[float],
    ) -> None: ...
    @overload
    def __init__(
        self,
        scanIdArray: List[int],
        cycleNumberArray: List[int],
        scanTimeArray: List[float],
    ) -> None: ...

    CycleNumberArray: List[int]  # readonly
    GridStep: float  # readonly
    PointCount: int  # readonly
    ScanIDArray: List[int]  # readonly
    ScanTimeArray: List[float]  # readonly

    def GetIndexOfNearestPointAbove(self, value_: float) -> int: ...
    def GetPointByIndex(self, index: int) -> float: ...
    def GetIndexOfNearestPoint(self, value_: float) -> int: ...
    def GetCycleNumberByIndex(self, index: int) -> int: ...
    def GetScanIDByIndex(self, index: int) -> int: ...
    def GetScanTimeRange(self, firstScanIndex: int, nPoints: int) -> List[float]: ...
    def GetIndexOfNearestPointBelow(self, value_: float) -> int: ...
    def GetCycleNumberRange(self, firstScanIndex: int, nPoints: int) -> List[int]: ...

class Ridge:  # Class
    def __init__(
        self, scanSpace: Agilent.MassSpectrometry.DataAnalysis.FD.IScanSpace
    ) -> None: ...

    ComputedNoise: float  # readonly
    FirstScanIndex: int  # readonly
    HasCentroidFlightTimeInfo: bool  # readonly
    IsSaturated: bool  # readonly
    LastScanIndex: int  # readonly
    Length: int  # readonly
    LengthExPrecursorAndTrailer: int  # readonly
    MaxAbundancePointIndex: int  # readonly
    MaxPointIndex: int  # readonly
    MinPointIndex: int  # readonly
    NoiseFactor2: float  # readonly
    PrecursorLength: int  # readonly
    RidgeID: int  # readonly
    ScanSpace: Agilent.MassSpectrometry.DataAnalysis.FD.IScanSpace  # readonly
    TrailerLength: int  # readonly

    def Read(self, br: System.IO.BinaryReader) -> None: ...
    def Write(self, bw: System.IO.BinaryWriter) -> None: ...
    def GetFlightTimeRange(self, startOffset: int, nPoints: int) -> List[float]: ...
    def GetCentroidFlightTime(self, offsetFromRidgeStart: int) -> float: ...
    def Overlaps(
        self, other: Agilent.MassSpectrometry.DataAnalysis.FD.Ridge
    ) -> bool: ...
    def GetFlightTime(self, offsetFromRidgeStart: int) -> float: ...
    def GetCentroidFlightTimeRange(
        self, startOffset: int, nPoints: int
    ) -> List[float]: ...
    @overload
    def FindPeaks(
        self, fd: Agilent.MassSpectrometry.DataAnalysis.FD.FeatureDetector
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.Feature
    ]: ...
    @overload
    def FindPeaks(
        self,
        fd: Agilent.MassSpectrometry.DataAnalysis.FD.FeatureDetector,
        smoothingKernel: Agilent.MassSpectrometry.DataAnalysis.FD.GaussianSmoothingKernel,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.Feature
    ]: ...
    def IsSaturatedAtScan(self, scanIndex: int) -> bool: ...
    def GetAbundance(self, offsetFromRidgeStart: int) -> float: ...
    def GetApexIndex(self, offsetFromRidgeStart: int) -> int: ...
    def GetAbundanceRange(self, startOffset: int, nPoints: int) -> List[float]: ...
    def ComputeQuartileBasedSignificanceRatio(self) -> float: ...
    def GetSaturatedRange(
        self, scanIndex: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.FD.SaturatedRange: ...

    # Nested Types

    class LengthComparer(
        System.Collections.Generic.IComparer[
            Agilent.MassSpectrometry.DataAnalysis.FD.Ridge
        ]
    ):  # Class
        def __init__(self) -> None: ...
        def Compare(
            self,
            a: Agilent.MassSpectrometry.DataAnalysis.FD.Ridge,
            b: Agilent.MassSpectrometry.DataAnalysis.FD.Ridge,
        ) -> int: ...

class RidgeDetectionCancelled(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self, sender: Any, callback: System.AsyncCallback, object: Any
    ) -> System.IAsyncResult: ...
    def Invoke(self, sender: Any) -> None: ...

class RidgeDetectionCompleted(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self, sender: Any, callback: System.AsyncCallback, object: Any
    ) -> System.IAsyncResult: ...
    def Invoke(self, sender: Any) -> None: ...

class RidgeDetectionParams:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, xmlFilePath: str) -> None: ...
    @overload
    def __init__(
        self, other: Agilent.MassSpectrometry.DataAnalysis.FD.RidgeDetectionParams
    ) -> None: ...

    PARAMETER_FILE: str = ...  # static # readonly

    ExtendedRange: bool
    MinDynamicRangeInNoiseUnits: float
    MinDynamicRangeInNoiseUnitsLC: float
    MinPrecursorLength: int
    MinRidgeLength: int
    MinTrailerLength: int
    NSlicesToSearch: int
    RidgeMapType: Agilent.MassSpectrometry.DataAnalysis.FD.RidgeMappingType
    ScanModeOnly: bool

    def Equals(
        self, other: Agilent.MassSpectrometry.DataAnalysis.FD.RidgeDetectionParams
    ) -> bool: ...
    def Clone(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.FD.RidgeDetectionParams: ...

class RidgeDetectionStarted(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        nScanRecords: int,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(self, sender: Any, nScanRecords: int) -> None: ...

class RidgeDetectionStepDone(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        scanRecordIndex: int,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(self, sender: Any, scanRecordIndex: int) -> None: ...

class RidgeDetector(System.IDisposable):  # Class
    def __init__(
        self,
        scanSpace: Agilent.MassSpectrometry.DataAnalysis.FD.IScanSpace,
        fd: Agilent.MassSpectrometry.DataAnalysis.FD.FeatureDetector,
        rdParams: Agilent.MassSpectrometry.DataAnalysis.FD.RidgeDetectionParams,
    ) -> None: ...

    FeatureDetector: (
        Agilent.MassSpectrometry.DataAnalysis.FD.FeatureDetector
    )  # readonly
    NoiseFactor2: float  # readonly
    RidgeDetectionParams: (
        Agilent.MassSpectrometry.DataAnalysis.FD.RidgeDetectionParams
    )  # readonly
    RidgeList: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.Ridge
    ]  # readonly
    SaturationLimit: float  # readonly
    ScanSpace: Agilent.MassSpectrometry.DataAnalysis.FD.IScanSpace  # readonly

    def KeepOnlyRidgesWithFeatures(
        self,
        features: System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.FD.Feature
        ],
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.Ridge
    ]: ...
    def CompleteRidgeDetection(self) -> None: ...
    def DebugWriteRidgeStats(
        self,
        features: System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.FD.Feature
        ],
    ) -> None: ...
    @staticmethod
    def GetRidgeLengthHistogram(
        ridges: System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.FD.Ridge
        ],
        nBins: int,
    ) -> List[int]: ...
    def ProcessSpectrum(
        self, spectrum: Agilent.MassSpectrometry.DataAnalysis.FD.IProfileSpectrum
    ) -> None: ...
    def Dispose(self) -> None: ...

class RidgeMappingType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Latest: Agilent.MassSpectrometry.DataAnalysis.FD.RidgeMappingType = (
        ...
    )  # static # readonly
    LatestOverMax: Agilent.MassSpectrometry.DataAnalysis.FD.RidgeMappingType = (
        ...
    )  # static # readonly
    MaxAbundance: Agilent.MassSpectrometry.DataAnalysis.FD.RidgeMappingType = (
        ...
    )  # static # readonly
    MaxOverLatest: Agilent.MassSpectrometry.DataAnalysis.FD.RidgeMappingType = (
        ...
    )  # static # readonly

class SampleFeatureDetector:  # Class
    @overload
    def __init__(self, sampleDataPath: str) -> None: ...
    @overload
    def __init__(
        self,
        sampleDataPath: str,
        rdParams: Agilent.MassSpectrometry.DataAnalysis.FD.RidgeDetectionParams,
        fdParams: Agilent.MassSpectrometry.DataAnalysis.FD.FeatureDetectionParams,
    ) -> None: ...

    DefaultMassCal: ITimeToMassConversion  # readonly
    FeatureDetectionParams: (
        Agilent.MassSpectrometry.DataAnalysis.FD.FeatureDetectionParams
    )  # readonly
    IsRidgeDetectionCancelled: bool  # readonly
    RidgeDetectionParams: (
        Agilent.MassSpectrometry.DataAnalysis.FD.RidgeDetectionParams
    )  # readonly

    def CancelRidgeDetection(self) -> None: ...
    def GetSpectrumDataAccessForMassCal(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.FD.SpectrumDataAccess: ...
    def GetRidgeDetector(
        self, scanSpace: Agilent.MassSpectrometry.DataAnalysis.FD.IScanSpace
    ) -> Agilent.MassSpectrometry.DataAnalysis.FD.RidgeDetector: ...
    def DetectFeaturesInRidges(
        self,
        sampleRidges: Agilent.MassSpectrometry.DataAnalysis.FD.ISampleRidges,
        sampleFeatures: Agilent.MassSpectrometry.DataAnalysis.FD.ISampleFeatures,
    ) -> None: ...
    def GetFeatureDetector(
        self, scanSpace: Agilent.MassSpectrometry.DataAnalysis.FD.IScanSpace
    ) -> Agilent.MassSpectrometry.DataAnalysis.FD.FeatureDetector: ...
    def DetectRidges(
        self, sampleRidges: Agilent.MassSpectrometry.DataAnalysis.FD.ISampleRidges
    ) -> bool: ...
    def OnRidgeDetectionCancelled(self) -> None: ...

    FeatureDetectionCompleted: (
        Agilent.MassSpectrometry.DataAnalysis.FD.FeatureDetectionCompleted
    )  # Event
    FeatureDetectionStarted: (
        Agilent.MassSpectrometry.DataAnalysis.FD.FeatureDetectionStarted
    )  # Event
    RidgeDetectionCancelled: (
        Agilent.MassSpectrometry.DataAnalysis.FD.RidgeDetectionCancelled
    )  # Event
    RidgeDetectionCompleted: (
        Agilent.MassSpectrometry.DataAnalysis.FD.RidgeDetectionCompleted
    )  # Event
    RidgeDetectionStarted: (
        Agilent.MassSpectrometry.DataAnalysis.FD.RidgeDetectionStarted
    )  # Event
    RidgeDetectionStepDone: (
        Agilent.MassSpectrometry.DataAnalysis.FD.RidgeDetectionStepDone
    )  # Event

class SaturatedFeatureRecoveryStatus(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Bootstrapped: (
        Agilent.MassSpectrometry.DataAnalysis.FD.SaturatedFeatureRecoveryStatus
    ) = ...  # static # readonly
    Cancelled: (
        Agilent.MassSpectrometry.DataAnalysis.FD.SaturatedFeatureRecoveryStatus
    ) = ...  # static # readonly
    CrossSample: (
        Agilent.MassSpectrometry.DataAnalysis.FD.SaturatedFeatureRecoveryStatus
    ) = ...  # static # readonly
    HighRSD: Agilent.MassSpectrometry.DataAnalysis.FD.SaturatedFeatureRecoveryStatus = (
        ...
    )  # static # readonly
    InvalidStatus: (
        Agilent.MassSpectrometry.DataAnalysis.FD.SaturatedFeatureRecoveryStatus
    ) = ...  # static # readonly
    NonSmoothTemplate: (
        Agilent.MassSpectrometry.DataAnalysis.FD.SaturatedFeatureRecoveryStatus
    ) = ...  # static # readonly
    Normal: Agilent.MassSpectrometry.DataAnalysis.FD.SaturatedFeatureRecoveryStatus = (
        ...
    )  # static # readonly

class SaturatedRange:  # Class
    @overload
    def __init__(
        self,
        abundance: List[int],
        satThreshold: float,
        pointRange: Agilent.MassSpectrometry.DataAnalysis.FD.IntRange,
        apexPointIndex: int,
        maxAbundance: int,
    ) -> None: ...
    @overload
    def __init__(
        self,
        pointRange: Agilent.MassSpectrometry.DataAnalysis.FD.IntRange,
        xRange: Agilent.MassSpectrometry.DataAnalysis.FD.DoubleRange,
        apexPointIndex: int,
        maxAbundance: int,
    ) -> None: ...

    ApexPointIndex: int  # readonly
    InterpolatedRange: Agilent.MassSpectrometry.DataAnalysis.FD.DoubleRange  # readonly
    MaxAbundance: int  # readonly
    PointRange: Agilent.MassSpectrometry.DataAnalysis.FD.IntRange  # readonly

    def Overlaps(self, minPtIndex: int, maxPtIndex: int) -> bool: ...
    def Contains(self, pointIndex: int) -> bool: ...

class SaturationRecoveryRequest:  # Class
    @overload
    def __init__(
        self,
        satFeature: Agilent.MassSpectrometry.DataAnalysis.FD.Feature,
        templateCandidateFeatures: System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.FD.Feature
        ],
        fdParams: Agilent.MassSpectrometry.DataAnalysis.FD.FeatureDetectionParams,
    ) -> None: ...
    @overload
    def __init__(
        self,
        satFeature: Agilent.MassSpectrometry.DataAnalysis.FD.Feature,
        templateFeature: Agilent.MassSpectrometry.DataAnalysis.FD.Feature,
        templateScaleFactor: float,
        fdParams: Agilent.MassSpectrometry.DataAnalysis.FD.FeatureDetectionParams,
    ) -> None: ...

    FeatureDetectionParams: (
        Agilent.MassSpectrometry.DataAnalysis.FD.FeatureDetectionParams
    )  # readonly
    IsCrossSampleRecovery: bool  # readonly
    SaturatedFeature: Agilent.MassSpectrometry.DataAnalysis.FD.Feature  # readonly
    TemplateCandidateFeatures: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.Feature
    ]  # readonly
    TemplateScaleFactor: float  # readonly

class SaturationRecoveryResult:  # Class
    IsSuccessful: bool  # readonly
    RestoredAbundance: List[float]  # readonly
    RestoredApexOffset: int  # readonly
    Template: (
        Agilent.MassSpectrometry.DataAnalysis.FD.SaturationRecoveryTemplate
    )  # readonly

class SaturationRecoveryTemplate:  # Class
    def __init__(
        self,
        req: Agilent.MassSpectrometry.DataAnalysis.FD.SaturationRecoveryRequest,
        useIsotopesOnly: bool,
        allowKinks: bool,
        useSaturatedFeatures: bool,
        minFrontPoints: int,
        minTailPoints: int,
    ) -> None: ...

    ApexScanOffset: int  # readonly
    EndScanIndex: int  # readonly
    FeatureCount: int  # readonly
    FeatureDetectionParams: (
        Agilent.MassSpectrometry.DataAnalysis.FD.FeatureDetectionParams
    )  # readonly
    FitRSD: float  # readonly
    FitYOffset: float  # readonly
    FitYScale: float  # readonly
    IsotopeCount: int  # readonly
    Length: int  # readonly
    NumberOfFitPoints: int  # readonly
    Request: (
        Agilent.MassSpectrometry.DataAnalysis.FD.SaturationRecoveryRequest
    )  # readonly
    SatFeature: Agilent.MassSpectrometry.DataAnalysis.FD.Feature  # readonly
    StartScanIndex: int  # readonly
    Status: (
        Agilent.MassSpectrometry.DataAnalysis.FD.SaturatedFeatureRecoveryStatus
    )  # readonly
    TotalIsotopeCount: int  # readonly

class SaturationRecoveryTemplateType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    All: Agilent.MassSpectrometry.DataAnalysis.FD.SaturationRecoveryTemplateType = (
        ...
    )  # static # readonly
    ComponentBased: (
        Agilent.MassSpectrometry.DataAnalysis.FD.SaturationRecoveryTemplateType
    ) = ...  # static # readonly
    IsotopesOnly: (
        Agilent.MassSpectrometry.DataAnalysis.FD.SaturationRecoveryTemplateType
    ) = ...  # static # readonly

class ScanAxis(Agilent.MassSpectrometry.DataAnalysis.FD.IAxisGrid):  # Class
    def __init__(self, xArray: List[float]) -> None: ...

    Is2GHzData: bool  # readonly
    IsMass: bool  # readonly
    PointCount: int  # readonly
    XArray: List[float]  # readonly
    XStart: float  # readonly
    XStep: float  # readonly

    def GetIndexOfNearestPointAbove(self, value_: float) -> int: ...
    def GetPointByIndex(self, index: int) -> float: ...
    def GetIndexOfNearestPointBelow(self, value_: float) -> int: ...
    def GetIndexOfNearestPoint(self, value_: float) -> int: ...

class ScanConditions(
    System.IEquatable[Agilent.MassSpectrometry.DataAnalysis.FD.ScanConditions]
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, scanRecord: ScanRecord) -> None: ...
    @overload
    def __init__(
        self, scanType: MSScanType, polarity: IonPolarity, mzOfInterest: float
    ) -> None: ...
    @overload
    def __init__(
        self,
        scanType: MSScanType,
        polarity: IonPolarity,
        mzOfInterest: float,
        collisionEnergy: float,
        fragmentorVoltage: float,
    ) -> None: ...

    CollisionEnergy: float  # readonly
    FragmentorVoltage: float  # readonly
    IonPolarity: IonPolarity  # readonly
    MzOfInterest: float  # readonly
    ScanAxis: Agilent.MassSpectrometry.DataAnalysis.FD.ScanAxis  # readonly
    ScanType: MSScanType  # readonly

    @staticmethod
    def Read(
        br: System.IO.BinaryReader, readCEFV: bool
    ) -> Agilent.MassSpectrometry.DataAnalysis.FD.ScanConditions: ...
    def Equals(
        self, other: Agilent.MassSpectrometry.DataAnalysis.FD.ScanConditions
    ) -> bool: ...
    def OverlapsFragmentorVoltageRange(self, fvRange: IRange) -> bool: ...
    def OverlapsPolarityFilter(self, polarityFilter: IonPolarity) -> bool: ...
    def Write(self, bw: System.IO.BinaryWriter) -> None: ...
    def ConsistentWith(self, scanRecord: ScanRecord) -> bool: ...
    @overload
    def OverlapsMzOfInterestRange(self, mzOfInterestRange: IRange) -> bool: ...
    @overload
    def OverlapsMzOfInterestRange(
        self, mzOfInterestRanges: RangeCollection
    ) -> bool: ...
    def OverlapsCollisionEnergyRange(self, ceRange: IRange) -> bool: ...
    def OverlapsScanTypeFilter(self, scanTypeFilter: MSScanType) -> bool: ...
    def ToString(self) -> str: ...

class ScanSpace(Agilent.MassSpectrometry.DataAnalysis.FD.IScanSpace):  # Class
    def __init__(
        self,
        scanConditions: Agilent.MassSpectrometry.DataAnalysis.FD.ScanConditions,
        rtAxis: Agilent.MassSpectrometry.DataAnalysis.FD.RTAxis,
        scanAxis: Agilent.MassSpectrometry.DataAnalysis.FD.ScanAxis,
        nScans: int,
    ) -> None: ...

    IsNull: bool  # readonly
    IsOpen: bool  # readonly
    RTAxis: Agilent.MassSpectrometry.DataAnalysis.FD.RTAxis  # readonly
    ScanAxis: Agilent.MassSpectrometry.DataAnalysis.FD.ScanAxis  # readonly
    ScanConditions: Agilent.MassSpectrometry.DataAnalysis.FD.ScanConditions  # readonly

    @staticmethod
    def Read(
        scanConditions: Agilent.MassSpectrometry.DataAnalysis.FD.ScanConditions,
        br: System.IO.BinaryReader,
        readCycleNumbers: bool,
    ) -> Agilent.MassSpectrometry.DataAnalysis.FD.IScanSpace: ...
    @staticmethod
    def Write(
        scanSpace: Agilent.MassSpectrometry.DataAnalysis.FD.IScanSpace,
        bw: System.IO.BinaryWriter,
    ) -> None: ...

class SmoothingType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    SmoothFeatures: Agilent.MassSpectrometry.DataAnalysis.FD.SmoothingType = (
        ...
    )  # static # readonly
    SmoothRidges: Agilent.MassSpectrometry.DataAnalysis.FD.SmoothingType = (
        ...
    )  # static # readonly

class SpectrumApex:  # Class
    @overload
    def __init__(
        self,
        xApexIndex: int,
        xAxis: Agilent.MassSpectrometry.DataAnalysis.FD.ScanAxis,
        y: List[int],
    ) -> None: ...
    @overload
    def __init__(
        self,
        xApexIndex: int,
        xAxis: Agilent.MassSpectrometry.DataAnalysis.FD.ScanAxis,
        y: List[int],
        centroidType: Agilent.MassSpectrometry.DataAnalysis.FD.CentroidType,
    ) -> None: ...

    CentroidType: Agilent.MassSpectrometry.DataAnalysis.FD.CentroidType  # readonly
    CentroidX: float  # readonly
    Index: int  # readonly
    InterpolatedX: float  # readonly
    InterpolatedY: float  # readonly
    IsInterpolated: bool  # readonly
    Y: int  # readonly

    @staticmethod
    def MedianFilter(a0: float, a1: float, a2: float) -> float: ...
    @overload
    @staticmethod
    def DoParabolicFit(
        x1: float,
        x2: float,
        x3: float,
        y1: float,
        y2: float,
        y3: float,
        a0: float,
        a1: float,
        a2: float,
    ) -> bool: ...
    @overload
    @staticmethod
    def DoParabolicFit(
        apexIndex: int, y1: int, y2: int, y3: int, a0: float, a1: float, a2: float
    ) -> bool: ...

class SpectrumDataAccess:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, scanModeOnly: bool) -> None: ...

    DefaultMassCal: ITimeToMassConversion  # readonly
    GotProfileData: bool  # readonly
    IsOpen: bool  # readonly
    IsTofData: bool  # readonly
    SampleDataPath: str  # readonly
    ScanRecordCount: int  # readonly

    def Open(self, sampleDataPath: str) -> None: ...
    def GetTimeToMassConversion(self, scanIndex: int) -> ITimeToMassConversion: ...
    def GetProfileSpectrum(
        self, scanNumber: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.FD.IProfileSpectrum: ...
    def Close(self) -> None: ...
    @staticmethod
    def GetDefaultMassCal(sampleDataPath: str) -> ITimeToMassConversion: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")
from .Agilent.MassSpectrometry.DataAnalysis import IFunction

# Stubs for namespace: Mathematics

class BinarySearch:  # Class
    def __init__(self) -> None: ...
    @overload
    @staticmethod
    def GetIndexLeftOf(list: List[Any], target: System.IComparable) -> int: ...
    @overload
    @staticmethod
    def GetIndexLeftOf(
        list: List[Any], start: int, end: int, target: System.IComparable
    ) -> int: ...

class Clustering:  # Class
    def __init__(self) -> None: ...

    NumClusters: int  # readonly

    def GetCluster(self, iCluster: int) -> List[int]: ...
    def Run(self) -> None: ...

class ClusteringMinSpanningTree(Mathematics.Clustering):  # Class
    def __init__(self, disimilarity: Mathematics.MatrixSymmetric) -> None: ...

    MinNumVectorForAuto: int  # static # readonly
    TheProjection: Mathematics.ClusteringMinSpanningTree.Projection  # readonly

    @overload
    def Run(self, iNumClusterDesired: int, iMinClusterSize: int) -> None: ...
    @overload
    def Run(self) -> None: ...

    # Nested Types

    class Projection:  # Class
        def __init__(
            self,
            engine: Mathematics.ClusteringMinSpanningTree,
            distances: Mathematics.MatrixSymmetric,
        ) -> None: ...
        def GetNodes(
            self,
        ) -> List[Mathematics.ClusteringMinSpanningTree.Projection.Node]: ...
        def GetBounds(
            self, fMinX: float, fMaxX: float, fMinY: float, fMaxY: float
        ) -> None: ...
        def GetEdges(
            self,
        ) -> List[Mathematics.ClusteringMinSpanningTree.Projection.Edge]: ...

        # Nested Types

        class Edge:  # Class
            def __init__(
                self,
                p1: Mathematics.ClusteringMinSpanningTree.Projection.Point,
                p2: Mathematics.ClusteringMinSpanningTree.Projection.Point,
                iTreeID: int,
            ) -> None: ...

            m_iTreeID: int
            m_node1: Mathematics.ClusteringMinSpanningTree.Projection.Point
            m_node2: Mathematics.ClusteringMinSpanningTree.Projection.Point

        class Node:  # Class
            def __init__(
                self,
                iTreeID: int,
                iObjectID: int,
                p: Mathematics.ClusteringMinSpanningTree.Projection.Point,
            ) -> None: ...

            m_iObjectID: int
            m_iTreeID: int
            m_point: Mathematics.ClusteringMinSpanningTree.Projection.Point

        class Point:  # Struct
            def __init__(self, fX: float, fY: float) -> None: ...

            m_fX: float
            m_fY: float

class ClusteringSequential:  # Class
    def __init__(
        self,
        input: List[Mathematics.ClusteringSequential.IElement],
        thresholds: List[IFunction],
    ) -> None: ...

    ClusterCount: int  # readonly

    @staticmethod
    def Distance(
        v1: Mathematics.Vector, v2: Mathematics.Vector, factors: Mathematics.Vector
    ) -> float: ...
    def GetCluster(
        self, clusterIndex: int
    ) -> List[Mathematics.ClusteringSequential.IElement]: ...
    def ClearClusterData(self, clusterIndex: int) -> None: ...
    def Run(self) -> None: ...

    # Nested Types

    class IElement(object):  # Interface
        DataDimension: int  # readonly
        Weight: float  # readonly

        def GetData(self, dimensionIndex: int) -> float: ...

class ClusteringSequential2dGrid(Mathematics.ClusteringSequential):  # Class
    def __init__(
        self,
        input: List[Mathematics.ClusteringSequential.IElement],
        thresholds: List[IFunction],
        ranges: List[Mathematics.RangeDouble],
        gridSizes: List[float],
    ) -> None: ...
    def Run(self) -> None: ...

class FFTSpectrum:  # Class
    @overload
    def __init__(self, aTimeSeries: List[float]) -> None: ...
    @overload
    def __init__(self, spectrum: List[float], timeSeriesLength: int) -> None: ...
    def LowPass(self, dT1: float, dT2: float) -> None: ...
    def GetTimeSeries(self) -> List[float]: ...
    def BandPass(self, dT1: float, dT2: float, dT3: float, dT4: float) -> None: ...

class FunctionXml:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def FromXml(siblings: System.Xml.XmlNodeList, name: str) -> IFunction: ...
    @staticmethod
    def ToXml(
        doc: System.Xml.XmlDocument, function: IFunction, name: str
    ) -> System.Xml.XmlElement: ...

class Graph:  # Class
    def __init__(self) -> None: ...

    AveSqDev: float  # readonly
    AverageWeight: float  # readonly

    @staticmethod
    def FindEdge(
        n1: Mathematics.Graph.Node, n2: Mathematics.Graph.Node
    ) -> Mathematics.Graph.Edge: ...

    # Nested Types

    class Edge:  # Class
        def __init__(
            self,
            node1: Mathematics.Graph.Node,
            node2: Mathematics.Graph.Node,
            fWeight: float,
        ) -> None: ...

        m_fWeight: float
        m_node1: Mathematics.Graph.Node
        m_node2: Mathematics.Graph.Node

    class Node:  # Class
        def __init__(self, iID: int) -> None: ...

        m_iID: int
        m_lstEdges: System.Collections.Generic.List[Mathematics.Graph.Edge]

        ID: int  # readonly

class HuffmanCompressedData(Generic[T]):  # Class
    @overload
    def __init__(self, symbolStream: List[T]) -> None: ...
    @overload
    def __init__(
        self,
        compressedData: List[int],
        unpacker: Mathematics.HuffmanCompressedData.UnpackSymbols[T],
    ) -> None: ...
    def GetCompressedData(
        self, packer: Mathematics.HuffmanCompressedData.PackSymbols[T]
    ) -> List[int]: ...
    def RetrieveOriginalData(self) -> List[T]: ...

    # Nested Types

    class PackSymbols(
        System.MulticastDelegate,
        Generic[T],
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, object: Any, method: System.IntPtr) -> None: ...
        def EndInvoke(self, result: System.IAsyncResult) -> List[int]: ...
        def BeginInvoke(
            self, data: List[T], callback: System.AsyncCallback, object: Any
        ) -> System.IAsyncResult: ...
        def Invoke(self, data: List[T]) -> List[int]: ...

    class UnpackSymbols(
        System.MulticastDelegate,
        Generic[T],
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, object: Any, method: System.IntPtr) -> None: ...
        def EndInvoke(self, offset: int, result: System.IAsyncResult) -> List[T]: ...
        def BeginInvoke(
            self,
            compressed: List[int],
            offset: int,
            callback: System.AsyncCallback,
            object: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(self, compressed: List[int], offset: int) -> List[T]: ...

class HuffmanCompressor(Generic[T]):  # Class
    def __init__(self) -> None: ...
    def GetCompressedData(
        self,
        symbolStream: List[T],
        packer: Mathematics.HuffmanCompressor.PackSymbols[T],
    ) -> List[int]: ...
    def GetUncompressedData(
        self,
        compressedData: List[int],
        offset: int,
        unpacker: Mathematics.HuffmanCompressor.UnpackSymbols[T],
    ) -> List[T]: ...
    def Compress(self, symbolStream: List[T]) -> None: ...

    # Nested Types

    class PackSymbols(
        System.MulticastDelegate,
        Generic[T],
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, object: Any, method: System.IntPtr) -> None: ...
        def EndInvoke(self, result: System.IAsyncResult) -> List[int]: ...
        def BeginInvoke(
            self, data: List[T], callback: System.AsyncCallback, object: Any
        ) -> System.IAsyncResult: ...
        def Invoke(self, data: List[T]) -> List[int]: ...

    class UnpackSymbols(
        System.MulticastDelegate,
        Generic[T],
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, object: Any, method: System.IntPtr) -> None: ...
        def EndInvoke(self, offset: int, result: System.IAsyncResult) -> List[T]: ...
        def BeginInvoke(
            self,
            compressed: List[int],
            offset: int,
            callback: System.AsyncCallback,
            object: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(self, compressed: List[int], offset: int) -> List[T]: ...

class IClassifierDiscrimativeRule(object):  # Interface
    Reversed: Mathematics.IClassifierDiscrimativeRule  # readonly

    def Test(self, unknown: Mathematics.Vector) -> float: ...

class IClusteringSequentialElement(object):  # Interface
    DataDimension: int  # readonly
    Weight: float  # readonly

    def GetData(self, dimensionIndex: int) -> float: ...

class KernelVaringSmoother:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def Smooth(
        data: List[float],
        kernelProvider: Mathematics.KernelVaringSmoother.IKernelProvider,
        strength: float,
    ) -> List[float]: ...

    # Nested Types

    class IKernelProvider(object):  # Interface
        def GetKernel(
            self, dataIndex: int, strength: float, kernelStartOffset: int
        ) -> List[float]: ...

class ListCompressor(Generic[T]):  # Class
    def __init__(self, frequency: Dict[T, int]) -> None: ...
    def GetCompressedData(self, symbolStream: List[T]) -> List[int]: ...
    def GetUncompressedData(self, code: List[int], offset: int) -> List[T]: ...
    def Compress(self, symbolStream: List[T]) -> None: ...

class Matrix:  # Class
    @overload
    def __init__(self, rowSize: int, colSize: int) -> None: ...
    @overload
    def __init__(
        self, rowSize: int, colSize: int, rowStart: int, colStart: int
    ) -> None: ...

    ColSize: int  # readonly
    ColStart: int  # readonly
    def __getitem__(self, row: int, col: int) -> float: ...
    def __setitem__(self, row: int, col: int, value_: float) -> None: ...
    RowSize: int  # readonly
    RowStart: int  # readonly

    def SwapRow(self, row1: int, row2: int) -> None: ...
    def SingularValueDecomposition(
        self, U: Mathematics.Matrix, V: Mathematics.MatrixSquare, w: Mathematics.Vector
    ) -> None: ...
    def IsInSameSpace(self, m: Mathematics.Matrix) -> bool: ...
    def Clone(self) -> Mathematics.Matrix: ...
    def SwapCol(self, col1: int, col2: int) -> None: ...

class MatrixSquare(Mathematics.Matrix):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, size: int) -> None: ...
    @overload
    def __init__(self, size: int, rowStart: int, colStart: int) -> None: ...

    DiagonalRMS: float  # readonly
    IdentifyMatrix: Mathematics.MatrixSquare  # readonly
    Size: int  # readonly

    def InverseDot(self, b: Mathematics.Vector) -> Mathematics.Vector: ...

class MatrixSymmetric(Mathematics.MatrixSquare):  # Class
    @overload
    def __init__(self, size: int) -> None: ...
    @overload
    def __init__(self, size: int, rowStart: int) -> None: ...
    def __getitem__(self, row: int, col: int) -> float: ...
    def __setitem__(self, row: int, col: int, value_: float) -> None: ...
    @overload
    @staticmethod
    def NormMatrix(A: Mathematics.Matrix) -> Mathematics.MatrixSymmetric: ...
    @overload
    @staticmethod
    def NormMatrix(v: Mathematics.Vector) -> Mathematics.MatrixSymmetric: ...
    def InverseDot(self, b: Mathematics.Vector) -> Mathematics.Vector: ...

class MinSpanningTree(Mathematics.Graph):  # Class
    @overload
    def __init__(self, disimilarity: Mathematics.MatrixSymmetric) -> None: ...
    @overload
    def __init__(self, n: Mathematics.Graph.Node) -> None: ...

    Edges: System.Collections.Generic.List[Mathematics.Graph.Edge]  # readonly
    Nodes: System.Collections.Generic.List[Mathematics.Graph.Node]  # readonly
    NumNodes: int  # readonly

    @staticmethod
    def CollectNeighbors(
        edge: Mathematics.Graph.Edge,
        iMaxStepsForNeighbor: int,
        lstNeighborsInBranch1: System.Collections.Generic.List[
            System.Collections.Generic.List[Mathematics.Graph.Edge]
        ],
        lstNeighborsInBranch2: System.Collections.Generic.List[
            System.Collections.Generic.List[Mathematics.Graph.Edge]
        ],
    ) -> None: ...

class PrincipalComponentAnalysis:  # Class
    def __init__(self, vectors: List[Mathematics.Vector]) -> None: ...

    SingularValues: List[float]  # readonly

    def GetVariableLoadings(self, variableIndex: int) -> List[float]: ...
    def Run(self) -> None: ...
    def GetScores(self, observationIndex: int) -> List[float]: ...
    def GetLoadingVector(self, componentIndex: int) -> List[float]: ...

class RangeDouble:  # Struct
    def __init__(self, iMin: float, iMax: float) -> None: ...

    Max: float  # readonly
    Mid: float  # readonly
    Min: float  # readonly
    Span: float  # readonly

    @staticmethod
    def Expands(
        r1: Mathematics.RangeDouble, r2: Mathematics.RangeDouble
    ) -> Mathematics.RangeDouble: ...
    def GetHashCode(self) -> int: ...
    @overload
    def Includes(self, r: Mathematics.RangeDouble) -> bool: ...
    @overload
    def Includes(self, d: float) -> bool: ...
    def Equals(self, obj: Any) -> bool: ...

class RangeInt:  # Struct
    def __init__(self, iMin: int, iMax: int) -> None: ...

    InvalidValue: Mathematics.RangeInt  # static # readonly
    Max: int  # readonly
    Mid: int  # readonly
    Min: int  # readonly
    Span: int  # readonly

    @staticmethod
    def Expands(
        r1: Mathematics.RangeInt, r2: Mathematics.RangeInt
    ) -> Mathematics.RangeInt: ...
    def GetHashCode(self) -> int: ...
    @overload
    def Includes(self, r: Mathematics.RangeInt) -> bool: ...
    @overload
    def Includes(self, i: int) -> bool: ...
    def Equals(self, obj: Any) -> bool: ...

class Regression:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, userSpec: Mathematics.Regression.ModelSpec) -> None: ...

    ConstantZeroModel: Mathematics.Regression  # static # readonly
    def __getitem__(self, x: float) -> float: ...
    ObservationCount: int  # readonly
    Result: Mathematics.Vector  # readonly

    def Fit(self, dampingParam: float) -> None: ...
    def Clear(self) -> None: ...
    @overload
    def AddObservation(self, x: float, y: float) -> None: ...
    @overload
    def AddObservation(self, x: float, y: float, wieght: float) -> None: ...

    # Nested Types

    class ModelSpec:  # Class
        def __init__(self) -> None: ...

        equation: str
        spec: Dict[str, Any]

    class Observation:  # Struct
        def __init__(self, x: float, y: float, weight: float) -> None: ...

        Weight: float
        X: float
        Y: float

class RegressionGaussian(Mathematics.RegressionNonlinear):  # Class
    @overload
    def __init__(
        self,
        userSpe: Mathematics.Regression.ModelSpec,
        initialMode: Mathematics.Vector,
        maxIterationCount: int,
    ) -> None: ...
    @overload
    def __init__(
        self, initialMode: Mathematics.Vector, maxIterationCount: int
    ) -> None: ...

    ModelSpecification: Mathematics.Regression.ModelSpec  # static # readonly

class RegressionLegPoly(Mathematics.RegressionLinear):  # Class
    @overload
    def __init__(self, userSpec: Mathematics.Regression.ModelSpec) -> None: ...
    @overload
    def __init__(self, maxDegree: int) -> None: ...

    ModelSpecification: Mathematics.Regression.ModelSpec  # static # readonly

class RegressionLinear(Mathematics.Regression):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, userSpec: Mathematics.Regression.ModelSpec) -> None: ...

class RegressionNonlinear(Mathematics.Regression):  # Class
    @overload
    def __init__(
        self, initialMode: Mathematics.Vector, maxIterationCount: int
    ) -> None: ...
    @overload
    def __init__(
        self,
        userSpe: Mathematics.Regression.ModelSpec,
        initialMode: Mathematics.Vector,
        maxIterationCount: int,
    ) -> None: ...

class RegressionPolynomial(Mathematics.RegressionLinear):  # Class
    @overload
    def __init__(self, userSpec: Mathematics.Regression.ModelSpec) -> None: ...
    @overload
    def __init__(self, minDegree: int, maxDegree: int) -> None: ...

    ModelSpecification: Mathematics.Regression.ModelSpec  # static # readonly

class SVMTwoClass:  # Class
    def __init__(
        self, class1: List[Mathematics.Vector], class2: List[Mathematics.Vector]
    ) -> None: ...
    def Test(self, v: Mathematics.Vector, fScore: float) -> int: ...
    def Train(self, fittingDegree: float) -> bool: ...

class SavitzkyGolayCoeffients:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def GetCoefficients(
        polynomialDegree: int, pointCountOnLeft: int, pointCountOnRight: int
    ) -> List[float]: ...

class SpecialFunction:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def IncompleteBetaFunction(fA: float, fB: float, fX: float) -> float: ...
    @staticmethod
    def LegendrePolynomial(n: int, x: float) -> float: ...
    @staticmethod
    def Gauss(x: float, A: float, x0: float, sigma: float, b: float) -> float: ...
    @staticmethod
    def SavitzkyGolay(
        maxPolynomialDegree: int, letfLength: int, rightLength: int, derivativeDeg: int
    ) -> List[float]: ...

class Statistics:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def StudentTTest(v1: List[float], v2: List[float]) -> float: ...

class SvmOverFeatured:  # Class
    def __init__(self, trainingData: List[List[Mathematics.Vector]]) -> None: ...
    def GetWVector(self, targetClassIndex: int) -> Mathematics.Vector: ...
    def GetTrainScore(self, vectorIndex: int, targetClassIndex: int) -> float: ...
    def Test(self, v: Mathematics.Vector, fScore: float) -> int: ...
    def Train(self, fFittingDegree: float) -> bool: ...
    def Sensitivity(self, targetClassIndex: int, dimentionIndex: int) -> float: ...

class Taper:  # Class
    def __init__(self, samplingX: List[float], halfTaperSpan: float) -> None: ...

    MaxTaperLength: int  # readonly

    def GetTaper(self, centerIndex: int, taperStartIndex: int) -> List[float]: ...

class Vector:  # Class
    @overload
    def __init__(self, size: int) -> None: ...
    @overload
    def __init__(self, size: int, indexStart: int) -> None: ...

    AllElements: float
    IndexStart: int  # readonly
    def __getitem__(self, index: int) -> float: ...
    def __setitem__(self, index: int, value_: float) -> None: ...
    Size: int  # readonly

    def CorelationCoefficient(self, v: Mathematics.Vector) -> float: ...
    def IsInSameSpace(self, v: Mathematics.Vector) -> bool: ...
    def Normalize(self) -> None: ...
    @staticmethod
    def MemberwiseDivide(
        v1: Mathematics.Vector, v2: Mathematics.Vector
    ) -> Mathematics.Vector: ...
    @staticmethod
    def Mapping(
        input: Mathematics.Vector, mapper: List[IFunction]
    ) -> Mathematics.Vector: ...
    @staticmethod
    def Distance(v1: Mathematics.Vector, v2: Mathematics.Vector) -> float: ...
    def Clone(self) -> Mathematics.Vector: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.DataStorageECM.Common

class Command:  # Class
    def __init__(self) -> None: ...

    Group: str
    Name: str
    RequireReason: bool
    RequireUserValidation: bool

class CommandGroup:  # Class
    def __init__(self) -> None: ...

    Commands: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.DataStorageECM.Common.Command
    ]
    Name: str
    PrivilegeID: int

class CommandGroups:  # Class
    def __init__(self) -> None: ...

    CurrentSchemaVersion: int = ...  # static # readonly

    Groups: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.DataStorageECM.Common.CommandGroup
    ]
    SchemaVersion: int

class IViewModel(object):  # Interface
    ...

class Role:  # Class
    def __init__(self) -> None: ...

    PrivilegePrefix: str = ...  # static # readonly

    Name: str  # readonly
    Privileges: Iterable[str]  # readonly

    def HasPriviledge(self, name: str) -> bool: ...
    def SetPriviledge(self, name: str, value_: bool) -> None: ...



# -*- coding: utf-8 -*-

__all__ = ["pathsep"]

import sys

try:
    from os import pathsep
except ImportError:
    # We must be inside Non-standard IronPython2.7 environment where even standard module do not exist
    from System import IO, Environment

    pathsep = (
        ";" if str(Environment.OSVersion.Platform).lower().startswith("win") else ":"
    )

    try:
        python_path = (Environment.GetEnvironmentVariable("PYTHONPATH") or "").split(
            pathsep
        )
        default_python_path = [
            r"C:\Program Files (x86)\IronPython 2.7\Lib",
        ]

        std_lib_path = next(
            p
            for p in python_path + default_python_path
            if p != "" and IO.File.Exists(IO.Path.Combine(p, "__future__.py"))
        )
        sys.path.append(std_lib_path)

        # Incase the PYTHONPATH is not respected by .NET IronPython2
        from collections import OrderedDict

        sys.path = [
            p for p in OrderedDict.fromkeys(sys.path[:-1] + python_path) if p != ""
        ]

        if std_lib_path not in sys.path:
            sys.path.append(std_lib_path)
    except StopIteration:
        raise SystemError(
            "can not find python 2.7 standard lib, please set PYTHONPATH envrionment"
        )
    except (ImportError, SyntaxError):
        raise SystemError(
            "'{}' must be the wrong Python 2.7.5 standard lib path".format(std_lib_path)
        )

from os import environ

command_str = environ.pop("MH_CONSOLE_COMMAND_STRING", "")
if command_str != "" and __name__ not in ("mh_operator.legacy", "mh_operator_legacy"):
    try:
        exec(command_str)  # nosec
    except:
        import traceback

        traceback.print_exc()



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .DataModel import (
    IGraphicsParameter,
    IList,
    IReport,
    ISelectable,
    ISelectableContainer,
    ITable,
)
from .Template import IList, ITable

# Stubs for namespace: Agilent.MassHunter.ReportBuilder.Application

class IAppCommand(object):  # Interface
    def Execute(self) -> Any: ...

class IApplication(object):  # Interface
    MainWindow: System.Windows.Window  # readonly
    Report: IReport  # readonly
    Selected: ISelectable  # readonly

    def CreateInsertSelectableCommand(
        self,
    ) -> Agilent.MassHunter.ReportBuilder.Application.IInsertSelectableCommand: ...
    def CreateSetGraphicsParametersCommand(
        self,
    ) -> Agilent.MassHunter.ReportBuilder.Application.ISetGraphicsParametersCommand: ...
    def ExecuteCommand(
        self,
        command: Agilent.MassHunter.ReportBuilder.Application.IAppCommand,
        ret: Any,
    ) -> bool: ...
    def CanInsert(
        self,
        canInsert: System.Func[ISelectableContainer, bool],
        container: ISelectableContainer,
        index: int,
    ) -> bool: ...

class IInsertSelectableCommand(
    Agilent.MassHunter.ReportBuilder.Application.IAppCommand
):  # Interface
    def InsertTable(
        self, container: ISelectableContainer, index: int, table: ITable
    ) -> ITable: ...
    def InsertList(
        self, container: ISelectableContainer, index: int, list: IList
    ) -> IList: ...
    def InsertGraphics(
        self,
        container: ISelectableContainer,
        index: int,
        name: str,
        parameterNames: List[str],
    ) -> None: ...

class ISetGraphicsParametersCommand(
    Agilent.MassHunter.ReportBuilder.Application.IAppCommand
):  # Interface
    def SetParameter(self, parameter: IGraphicsParameter, value_: Any) -> None: ...

class SystemCommands:  # Class
    Alignment_Bottom: str = ...  # static # readonly
    Alignment_HCenter: str = ...  # static # readonly
    Alignment_Left: str = ...  # static # readonly
    Alignment_Right: str = ...  # static # readonly
    Alignment_Top: str = ...  # static # readonly
    Alignment_VCenter: str = ...  # static # readonly
    Edit_DataBindings: str = ...  # static # readonly
    Edit_Delete: str = ...  # static # readonly
    Edit_MoveDown: str = ...  # static # readonly
    Edit_MoveUp: str = ...  # static # readonly
    Edit_Redo: str = ...  # static # readonly
    Edit_TableColumns: str = ...  # static # readonly
    Edit_Undo: str = ...  # static # readonly
    File_Exit: str = ...  # static # readonly
    File_New: str = ...  # static # readonly
    File_Open: str = ...  # static # readonly
    File_Save: str = ...  # static # readonly
    File_SaveAs: str = ...  # static # readonly
    Font_Bold: str = ...  # static # readonly
    Font_Italic: str = ...  # static # readonly
    Font_Underline: str = ...  # static # readonly
    Help_About: str = ...  # static # readonly
    Help_Help: str = ...  # static # readonly
    Insert_Graphics: str = ...  # static # readonly
    Insert_Image: str = ...  # static # readonly
    Insert_List: str = ...  # static # readonly
    Insert_Page: str = ...  # static # readonly
    Insert_ScriptBox: str = ...  # static # readonly
    Insert_Table: str = ...  # static # readonly
    Insert_TableRow: str = ...  # static # readonly
    Insert_Textbox: str = ...  # static # readonly
    Preview_Preview: str = ...  # static # readonly
    Preview_Setup: str = ...  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import (
    IIonSpeciesDetails,
    IIsotopeClusterBase,
    IModificationSpecies,
    PeakFinderAlgorithmName,
    SpectralPeak,
)

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.MassHunter

class CompoundFilterParameters(
    CompoundFilters.IProteinFilterParameters,
    Agilent.MassSpectrometry.DataAnalysis.MassHunter.MfeFilterParameters,
    CompoundFilters.ICompoundFilterParameters,
    CompoundFilters.IGenericCompoundFilterParameters,
):  # Class
    def __init__(self) -> None: ...

    ChargeStateParameters: CompoundFilters.ChargeStateFilter.Parameter  # readonly
    IsotopePatternParameters: CompoundFilters.IsotopePatternFilter.Parameter  # readonly
    MinIonCountParamters: CompoundFilters.MinIonCountFilter.Parameter  # readonly
    NeutralModificationParameters: (
        CompoundFilters.NeutralModificationFilter.Parameter
    )  # readonly
    QualityScoreParameters: CompoundFilters.QualityScoreFilter.Parameter  # readonly
    TimePeakWidthParameters: CompoundFilters.PeakRtWidthFilter.Parameter  # readonly
    UunknownMassParameters: CompoundFilters.UnknownMassFilter.Parameter  # readonly

    def SetUnknownMassParameters(
        self, status: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus
    ) -> None: ...
    def GetNeutralModificationParameters(
        self,
        status: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus,
        modificationList: List[str],
    ) -> None: ...
    def GetChargeStateParameters(
        self,
        status: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus,
        minChargeCount: int,
        maxChargeCount: int,
        fullRangeRequired: bool,
    ) -> None: ...
    def GetIsotopePatternParameters(
        self,
        status: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus,
        templateFormula: str,
        massAccuracyCoefficients: List[float],
        relativeIntensityUncertainty: float,
        intensityPattern: List[float],
        intensityPatternUncertainty: List[float],
    ) -> None: ...
    def SetNeutralModificationParameters(
        self,
        status: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus,
        modificationList: List[str],
    ) -> None: ...
    def GetMinIonCountParameters(
        self,
        status: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus,
        minIonCount: int,
    ) -> None: ...
    def GetUnknownMassParameters(
        self, status: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus
    ) -> None: ...
    def SetChargeStateParameters(
        self,
        status: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus,
        minChargeCount: int,
        maxChargeCount: int,
        fullRangeRequired: bool,
    ) -> None: ...
    def SetIsotopePatternParameters(
        self,
        status: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus,
        templateFormula: str,
        massAccuracyCoefficients: List[float],
        relativeIntensityUncertainty: float,
        intensityPattern: List[float],
        intensityPatternUncertainty: List[float],
    ) -> None: ...
    def GetQualityScoreParameters(
        self,
        status: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus,
        minScore: float,
        maxScore: float,
    ) -> None: ...
    def GetPeakTimeWidthParameters(
        self,
        status: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus,
        minWidth: float,
        maxWidth: float,
    ) -> None: ...
    def SetMinIonCountParameters(
        self,
        status: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus,
        minIonCount: int,
    ) -> None: ...
    def SetQualityScoreParameters(
        self,
        status: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus,
        minScore: float,
        maxScore: float,
    ) -> None: ...
    def SetPeakTimeWidthParameters(
        self,
        status: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus,
        minWidth: float,
        maxWidth: float,
    ) -> None: ...

class FilterStatus(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Block: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus = (
        ...
    )  # static # readonly
    NotApplied: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus = (
        ...
    )  # static # readonly
    PassOnlyThese: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus = (
        ...
    )  # static # readonly

class IChargeState(object):  # Interface
    Abundance: float  # readonly
    HasPeak: bool  # readonly
    MZ: float  # readonly
    MaxHeight: float  # readonly
    PredictedMass: float  # readonly
    RetentionTime: float  # readonly
    Saturated: bool  # readonly
    Signal3Ds: List[
        Agilent.MassSpectrometry.DataAnalysis.MassHunter.ISignal3D
    ]  # readonly
    Z: int  # readonly

class IChemicalAndIonizationParameters(object):  # Interface
    IonSpeciesGroupingRulesNegative: (
        Agilent.MassSpectrometry.DataAnalysis.MassHunter.IIonSpeciesGroupingRules
    )  # readonly
    IonSpeciesGroupingRulesPositive: (
        Agilent.MassSpectrometry.DataAnalysis.MassHunter.IIonSpeciesGroupingRules
    )  # readonly
    IsotopeCharacteristics: (
        Agilent.MassSpectrometry.DataAnalysis.MassHunter.IsotopeCharacteristics
    )
    MaxChargeCount: int
    NeutralModifications: List[str]
    TargetedMassList: (
        Agilent.MassSpectrometry.DataAnalysis.MassHunter.ITargetedMassList
    )  # readonly

class ICoelutedProteinGroup(object):  # Interface
    Proteins: List[
        Agilent.MassSpectrometry.DataAnalysis.MassHunter.IProtein
    ]  # readonly
    RetentionTime: float  # readonly

class ICoelutionGroup(object):  # Interface
    Compounds: List[
        Agilent.MassSpectrometry.DataAnalysis.MassHunter.ICompound
    ]  # readonly
    RetentionTime: float  # readonly
    Saturated: bool  # readonly

class ICompound(object):  # Interface
    Abundance: float  # readonly
    AverageMass: float  # readonly
    AverageMassStandardDeviation: float  # readonly
    IsotopeClusters: List[
        Agilent.MassSpectrometry.DataAnalysis.MassHunter.IIsotopeCluster
    ]  # readonly
    LowestIsotopeMass: float  # readonly
    MassStandardDeviation: float  # readonly
    MaxHeight: float  # readonly
    MostReliableIsotopeCluster: (
        Agilent.MassSpectrometry.DataAnalysis.MassHunter.IIsotopeCluster
    )  # readonly
    QualityScore: float  # readonly
    RetentionTime: float  # readonly
    RetentionTimePeakWidth: float  # readonly
    Saturated: bool  # readonly

class IDataRangeParameters(object):  # Interface
    MaxMZ: float  # readonly
    MaxRetentionTime: float  # readonly
    MinMZ: float  # readonly
    MinRetentionTime: float  # readonly

    def SetMZRange(self, min: float, max: float) -> None: ...
    def SetRetentionTimeRange(self, min: float, max: float) -> None: ...

class IIonSpeciesGroupingRules(object):  # Interface
    ChargeCarrierList: List[
        Agilent.MassSpectrometry.DataAnalysis.MassHunter.UnitChargeCarrier
    ]
    DefaultUnitCharge: str

class IIsotope(object):  # Interface
    Abundance: float  # readonly
    MZ: float  # readonly
    MaxHeight: float  # readonly
    QualityScore: float  # readonly
    RetentionTime: float  # readonly
    RetentionTimePeakWidth: float  # readonly
    Saturated: bool  # readonly

class IIsotopeCluster(IIsotopeClusterBase):  # Interface
    Abundance: float  # readonly
    IonSpecies: IModificationSpecies  # readonly
    IonSpeciesDetails: IIonSpeciesDetails  # readonly
    Isotopes: List[
        Agilent.MassSpectrometry.DataAnalysis.MassHunter.IIsotope
    ]  # readonly
    LowestIsotopeMZ: float  # readonly
    MaxHeight: float  # readonly
    QualityScore: float  # readonly
    RetentionTime: float  # readonly
    RetentionTimePeakWidth: float  # readonly
    Saturated: bool  # readonly
    SaturationCorrectedIsotopePattern: List[SpectralPeak]  # readonly

class IProtein(object):  # Interface
    Abundance: float  # readonly
    IonSet: List[
        Agilent.MassSpectrometry.DataAnalysis.MassHunter.IChargeState
    ]  # readonly
    Mass: float  # readonly
    MassStandardDeviation: float  # readonly
    MaxHeight: float  # readonly
    RetentionTime: float  # readonly
    RetentionTimePeakWidth: float  # readonly
    Saturated: bool  # readonly

class IProteinFinderParameters(object):  # Interface
    ...

class IRawSpectrumAccessor(object):  # Interface
    FullSaturationLevel: float  # readonly
    Metadata: (
        Agilent.MassSpectrometry.DataAnalysis.MassHunter.SpectrumSetMetadata
    )  # readonly
    ScanCalibCoefficients: List[float]  # readonly
    ScanFirstXValue: float  # readonly
    ScanProfileIntensities: List[float]  # readonly
    ScanRetentionTimes: List[float]  # readonly
    SpectraType: (
        Agilent.MassSpectrometry.DataAnalysis.MassHunter.SpectraType
    )  # readonly
    TicIntensities: List[float]  # readonly

    def Close(self) -> None: ...
    def GetPeakList(
        self, mz: List[float], heights: List[float], errorCode: List[int]
    ) -> None: ...
    def Open(self) -> None: ...
    def UpdateScan(self, scanIndex: int, minMZ: float, maxMZ: float) -> None: ...

class IRetentionTimePeakFinderParameters(object):  # Interface
    RetentionTimePeakWidth: float
    SmoothingStrength: float

class ISignal3D(object):  # Interface
    Intensity: float  # readonly
    MZ: float  # readonly
    RetentionTime: float  # readonly
    Saturated: bool  # readonly
    ScanIndex: int  # readonly

class ISpectralPeakFinderParameters(object):  # Interface
    BaselineToleranceLength: float
    HeightThresholdTypeForProfileData: (
        Agilent.MassSpectrometry.DataAnalysis.MassHunter.SpectralPeakThresholdType
    )
    HeightThresholdValueForProfileData: float
    MaxPeakWidth: float  # readonly
    MinHeightForPeakDetectedData: float
    MinPeakWidth: float  # readonly
    PreferredAlgorithm: PeakFinderAlgorithmName
    SmoothingStrength: float

    def SetPeakWidthRange(self, min: float, max: float) -> None: ...

class ITargetedMassList(object):  # Interface
    MassList: List[float]
    MassToleranceCoefficients: List[float]
    UseMonoisotopicMass: bool

class IsotopeCharacteristics(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    AllElements: (
        Agilent.MassSpectrometry.DataAnalysis.MassHunter.IsotopeCharacteristics
    ) = ...  # static # readonly
    Averagine: (
        Agilent.MassSpectrometry.DataAnalysis.MassHunter.IsotopeCharacteristics
    ) = ...  # static # readonly
    Biological: (
        Agilent.MassSpectrometry.DataAnalysis.MassHunter.IsotopeCharacteristics
    ) = ...  # static # readonly
    CommonCompound: (
        Agilent.MassSpectrometry.DataAnalysis.MassHunter.IsotopeCharacteristics
    ) = ...  # static # readonly
    Glycan: Agilent.MassSpectrometry.DataAnalysis.MassHunter.IsotopeCharacteristics = (
        ...
    )  # static # readonly

class MfeFilterParameters(CompoundFilters.IGenericCompoundFilterParameters):  # Class
    def __init__(self) -> None: ...

    AbundanceParameters: CompoundFilters.AbundanceFilter.Parameter  # readonly
    LocationRangeParameters: CompoundFilters.LocationRangeFilter.Parameter  # readonly
    MassDefectParameters: CompoundFilters.MassDefectFilter.Parameter  # readonly
    SpecialMassParameters: CompoundFilters.SpecialMassFilter.Parameter  # readonly
    SpecialTimeParameters: CompoundFilters.SpecialTimeFilter.Parameter  # readonly
    TimeMassParameters: CompoundFilters.TimeMassFilter.Parameter  # readonly

    def SetSpecialMassParameters(
        self,
        status: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus,
        massList: List[float],
        massToleranceCoefficients: List[float],
        lowerLimitsForMassRanges: List[float],
        upperLimitsForMassRanges: List[float],
    ) -> None: ...
    def SetAbundanceParameters(
        self,
        status: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus,
        largestNCompounds: int,
        minAbsoluteAbundance: float,
        minRelativeAbundance: float,
        useHeightAsMetric: bool,
    ) -> None: ...
    def GetAbundanceParameters(
        self,
        status: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus,
        largestNCompounds: int,
        minAbsoluteAbundance: float,
        minRelativeAbundance: float,
        useHeightAsMetric: bool,
    ) -> None: ...
    def GetMassDefectParameters(
        self,
        status: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus,
        peptideLike: bool,
        targetDefectIntercept: float,
        targetDefectSlope: float,
        toleranceInterceptForPositiveDeviation: float,
        toleranceSlopeForPositiveDeviation: float,
        toleranceInterceptForNegativeDeviation: float,
        toleranceSlopeForNegativeDeviation: float,
    ) -> None: ...
    def SetSpecialTimeParameters(
        self,
        status: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus,
        timeList: List[float],
        timeToleranceCoefficients: List[float],
        lowerLimitsForTimeRanges: List[float],
        upperLimitsForTimeRanges: List[float],
    ) -> None: ...
    def SetMassDefectParameters(
        self,
        status: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus,
        peptideLike: bool,
        targetDefectIntercept: float,
        targetDefectSlope: float,
        toleranceInterceptForPositiveDeviation: float,
        toleranceSlopeForPositiveDeviation: float,
        toleranceInterceptForNegativeDeviation: float,
        toleranceSlopeForNegativeDeviation: float,
    ) -> None: ...
    def GetSpecialTimeParameters(
        self,
        status: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus,
        timeList: Sequence[float],
        timeToleranceCoefficients: List[float],
        lowerLimitsForTimeRanges: List[float],
        upperLimitsForTimeRanges: List[float],
    ) -> None: ...
    def GetSpecialMassParameters(
        self,
        status: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus,
        massList: Sequence[float],
        massToleranceCoefficients: List[float],
        lowerLimitsForMassRanges: List[float],
        upperLimitsForMassRanges: List[float],
    ) -> None: ...
    def GetLocationRangeParameters(
        self,
        status: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus,
        minRetentionTime: float,
        maxRetentionTime: float,
        minMass: float,
        maxMass: float,
    ) -> None: ...
    def SetLocationRangeParameters(
        self,
        status: Agilent.MassSpectrometry.DataAnalysis.MassHunter.FilterStatus,
        minRetentionTime: float,
        maxRetentionTime: float,
        minMass: float,
        maxMass: float,
    ) -> None: ...

class ProteinFilterParameters(
    CompoundFilters.IProteinFilterParameters,
    Agilent.MassSpectrometry.DataAnalysis.MassHunter.MfeFilterParameters,
    CompoundFilters.IGenericCompoundFilterParameters,
):  # Class
    def __init__(self) -> None: ...

    QualityScoreParameters: CompoundFilters.QualityScoreFilter.Parameter  # readonly
    TimePeakWidthParameters: CompoundFilters.PeakRtWidthFilter.Parameter  # readonly

class SpectraType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    PeakDected: Agilent.MassSpectrometry.DataAnalysis.MassHunter.SpectraType = (
        ...
    )  # static # readonly
    Profile: Agilent.MassSpectrometry.DataAnalysis.MassHunter.SpectraType = (
        ...
    )  # static # readonly
    Unspecified: Agilent.MassSpectrometry.DataAnalysis.MassHunter.SpectraType = (
        ...
    )  # static # readonly

class SpectralPeakThresholdType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Absolute: (
        Agilent.MassSpectrometry.DataAnalysis.MassHunter.SpectralPeakThresholdType
    ) = ...  # static # readonly
    SNRatio: (
        Agilent.MassSpectrometry.DataAnalysis.MassHunter.SpectralPeakThresholdType
    ) = ...  # static # readonly
    Unknown: (
        Agilent.MassSpectrometry.DataAnalysis.MassHunter.SpectralPeakThresholdType
    ) = ...  # static # readonly

class SpectrumSetMetadata:  # Class
    def __init__(self) -> None: ...

    CalibCoeffecientCount: int
    InstrumentType: (
        Agilent.MassSpectrometry.DataAnalysis.MassHunter.SpectrumSetMetadata.MSInstrumentType
    )
    InstrumentVersion: str
    MZBinWidthInNS: float
    MaxAcqMZ: float
    MaxCalibratedTimeRangeInNS: float
    MinAcqMZ: float
    MinCalibratedTimeRangeInNS: float
    Polarity: (
        Agilent.MassSpectrometry.DataAnalysis.MassHunter.SpectrumSetMetadata.MSPolarity
    )
    SourceType: (
        Agilent.MassSpectrometry.DataAnalysis.MassHunter.SpectrumSetMetadata.MSSourceType
    )

    # Nested Types

    class MSInstrumentType(
        System.IConvertible, System.IComparable, System.IFormattable
    ):  # Struct
        IonTrap: (
            Agilent.MassSpectrometry.DataAnalysis.MassHunter.SpectrumSetMetadata.MSInstrumentType
        ) = ...  # static # readonly
        QQQ: (
            Agilent.MassSpectrometry.DataAnalysis.MassHunter.SpectrumSetMetadata.MSInstrumentType
        ) = ...  # static # readonly
        QTOF: (
            Agilent.MassSpectrometry.DataAnalysis.MassHunter.SpectrumSetMetadata.MSInstrumentType
        ) = ...  # static # readonly
        QUAD: (
            Agilent.MassSpectrometry.DataAnalysis.MassHunter.SpectrumSetMetadata.MSInstrumentType
        ) = ...  # static # readonly
        TOF: (
            Agilent.MassSpectrometry.DataAnalysis.MassHunter.SpectrumSetMetadata.MSInstrumentType
        ) = ...  # static # readonly
        Unknown: (
            Agilent.MassSpectrometry.DataAnalysis.MassHunter.SpectrumSetMetadata.MSInstrumentType
        ) = ...  # static # readonly

    class MSPolarity(
        System.IConvertible, System.IComparable, System.IFormattable
    ):  # Struct
        Negative: (
            Agilent.MassSpectrometry.DataAnalysis.MassHunter.SpectrumSetMetadata.MSPolarity
        ) = ...  # static # readonly
        Positive: (
            Agilent.MassSpectrometry.DataAnalysis.MassHunter.SpectrumSetMetadata.MSPolarity
        ) = ...  # static # readonly
        Unknown: (
            Agilent.MassSpectrometry.DataAnalysis.MassHunter.SpectrumSetMetadata.MSPolarity
        ) = ...  # static # readonly

    class MSSourceType(
        System.IConvertible, System.IComparable, System.IFormattable
    ):  # Struct
        EI: (
            Agilent.MassSpectrometry.DataAnalysis.MassHunter.SpectrumSetMetadata.MSSourceType
        ) = ...  # static # readonly
        ESI: (
            Agilent.MassSpectrometry.DataAnalysis.MassHunter.SpectrumSetMetadata.MSSourceType
        ) = ...  # static # readonly
        MALDI: (
            Agilent.MassSpectrometry.DataAnalysis.MassHunter.SpectrumSetMetadata.MSSourceType
        ) = ...  # static # readonly
        Unkonwn: (
            Agilent.MassSpectrometry.DataAnalysis.MassHunter.SpectrumSetMetadata.MSSourceType
        ) = ...  # static # readonly

class UnitChargeCarrier:  # Struct
    def __init__(self, formula: str, isAnchor: bool) -> None: ...

    Formula: str  # readonly
    IsAnchor: bool  # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .ViewModel import (
    IBatchTableViewModel,
    IColumnLabelsViewModel,
    IControlPanelViewModel,
    ICustomizeRibbonViewModel,
    IGeneralSettingsViewModel,
    IManageViewModel,
    IOutliersViewModel,
    ISampleTypesViewModel,
    ITask,
    ITaskGroup,
)

# Stubs for namespace: Agilent.MassHunter.Quantitative.Startup.Edit.MainView

class ControlPanelGroup(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.NotifyPropertyBase,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(
        self,
        model: Agilent.MassHunter.Quantitative.Startup.Edit.MainView.ControlPanelViewModel,
        group: ITaskGroup,
    ) -> None: ...

    Group: ITaskGroup  # readonly
    Model: (
        Agilent.MassHunter.Quantitative.Startup.Edit.MainView.ControlPanelViewModel
    )  # readonly
    Tasks: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.MainView.ControlPanelTask
    ]  # readonly

class ControlPanelTask(System.Windows.DependencyObject):  # Class
    def __init__(
        self,
        model: Agilent.MassHunter.Quantitative.Startup.Edit.MainView.ControlPanelViewModel,
        task: ITask,
    ) -> None: ...

    IsSelectedProperty: System.Windows.DependencyProperty  # static

    IsSelected: bool
    Task: ITask  # readonly

class ControlPanelViewModel(
    System.Windows.DependencyObject, IControlPanelViewModel
):  # Class
    def __init__(
        self, window: Agilent.MassHunter.Quantitative.Startup.Edit.MainView.MainWindow
    ) -> None: ...

    AlwaysLoadConfigurationProperty: System.Windows.DependencyProperty  # static
    ConfigurationsProperty: System.Windows.DependencyProperty  # static
    DefaultConfigurationProperty: System.Windows.DependencyProperty  # static
    IsStartupRootFolderValidProperty: System.Windows.DependencyProperty  # static
    SelectedConfigurationProperty: System.Windows.DependencyProperty  # static
    SelectedTaskProperty: System.Windows.DependencyProperty  # static
    StartupRootFolderProperty: System.Windows.DependencyProperty  # static
    UserCanChooseConfigurationProperty: System.Windows.DependencyProperty  # static
    WindowTitleProperty: System.Windows.DependencyProperty  # static

    AlwaysLoadConfiguration: bool
    BatchTableViewModel: IBatchTableViewModel  # readonly
    ColumnLabelsViewModel: IColumnLabelsViewModel  # readonly
    Configurations: List[str]  # readonly
    CustomizeRibbonViewModel: ICustomizeRibbonViewModel  # readonly
    DefaultConfiguration: str
    GeneralSettingsViewModel: IGeneralSettingsViewModel  # readonly
    Groups: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.MainView.ControlPanelGroup
    ]  # readonly
    IsStartupRootFolderValid: bool  # readonly
    ManageViewModel: IManageViewModel  # readonly
    OutliersViewModel: IOutliersViewModel  # readonly
    SampleTypesViewModel: ISampleTypesViewModel  # readonly
    SelectedConfiguration: str
    SelectedTask: Agilent.MassHunter.Quantitative.Startup.Edit.MainView.ControlPanelTask
    StartupRootFolder: str
    TaskSelector: (
        Agilent.MassHunter.Quantitative.Startup.Edit.MainView.TaskSelector
    )  # readonly
    UserCanChooseConfiguration: bool
    Window: System.Windows.Window  # readonly
    WindowTitle: str

    def Initialize(self) -> None: ...
    def UpdateConfigurations(self) -> None: ...
    def EditSelectedConfiguration(self) -> None: ...

class MainWindow(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.IWindowService,
    Infragistics.Windows.Ribbon.IRibbonWindow,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Animation.IAnimatable,
    System.ComponentModel.ISupportInitialize,
    Infragistics.Windows.Ribbon.XamRibbonWindow,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.Windows.Markup.IAddChild,
    System.Windows.Markup.IComponentConnector,
    System.Windows.Markup.IHaveResources,
):  # Class
    def __init__(self) -> None: ...

    ToolManager: (
        Agilent.MassHunter.Quantitative.Startup.Edit.MainView.ToolManager
    )  # readonly

    def InitializeComponent(self) -> None: ...

class TaskSelector:  # Class
    def __init__(
        self,
        model: Agilent.MassHunter.Quantitative.Startup.Edit.MainView.ControlPanelViewModel,
    ) -> None: ...

    SelectedTask: Agilent.MassHunter.Quantitative.Startup.Edit.MainView.ControlPanelTask

class ToolManager(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.IToolManager,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolManager,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolbarsManager,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.ToolManagerBase,
):  # Class
    def __init__(
        self, ribbon: Infragistics.Windows.Ribbon.XamRibbon, uiState: Any
    ) -> None: ...
    def GetToolCaption(self, id: str) -> str: ...
    def RegisterScriptCategoryHandler(
        self, category: str, module: str, setState: str, execute: str
    ) -> None: ...
    def RegisterScriptToolHandler(
        self, id: str, module: str, setState: str, execute: str
    ) -> None: ...
    def GetImage(self, image: str) -> System.Windows.Media.Imaging.BitmapSource: ...



# type: ignore[attr-defined]
"""Awesome `mh-operator` provide interfaces and common routines for the Agilent MassHunter official SDK."""

import sys

__all__ = ["version", "get_version"]

if sys.version_info.major == 2:
    version = "unknown"
    get_version = lambda: "unknown"
else:
    from .version import get_version, version



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Interfaces import (
    IAcamlReader,
    IAcamlReaderWriter,
    IAcamlSignalLoader,
    IAcamlWriter,
)

# Stubs for namespace: Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.DataHandlers

class AcamlObjectStore:  # Class
    @staticmethod
    def IsInitialized(docId: System.Guid) -> bool: ...
    @staticmethod
    def UpdateDocumentBaseDirectory(docId: System.Guid, fileName: str) -> None: ...
    @staticmethod
    def Clear() -> None: ...
    @staticmethod
    def GetDocumentBaseDirectory(
        pathHelper: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
        docId: System.Guid,
    ) -> str: ...
    @staticmethod
    def GetDocumentFileName(docId: System.Guid) -> str: ...
    @staticmethod
    def Exists(docId: System.Guid) -> bool: ...
    @staticmethod
    def PrepareForDataModifications(
        docId: System.Guid,
    ) -> System.Threading.Tasks.Task[None]: ...

class AcamlReaderWriter(
    IAcamlReaderWriter,
    Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.DistributedAcaml.IAcamlReaderWriterServices,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, validateChecksum: bool, validateSchema: bool) -> None: ...

    EnforceAcamlBusinessRules: bool
    PrepareForDataModification: bool
    ValidateChecksumOnLoad: bool
    ValidateChecksumOnSave: bool
    ValidateSchemaOnLoad: bool
    ValidateSchemaOnSave: bool

    def CreateWriter(
        self,
        pathHelper: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
        acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML,
        fileName: str,
        saveOnlyChangedData: bool = ...,
        updateMetadata: bool = ...,
    ) -> IAcamlWriter: ...
    @staticmethod
    def MergeInjectionAcamls(
        sequenceAcaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML,
        injectionMeasDataIds: Iterable[System.Guid] = ...,
    ) -> None: ...
    @overload
    def LoadAcamlMetadata(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        path: str,
        createIfMissing: bool = ...,
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CustomObjects.IInjectionMetaData
    ]: ...
    @overload
    def LoadAcamlMetadata(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        path: str,
        version: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo,
        createIfMissing: bool = ...,
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CustomObjects.IInjectionMetaData
    ]: ...
    @overload
    def LoadAcamlMetadata(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        paths: Iterable[str],
        createIfMissing: bool = ...,
    ) -> Dict[
        str,
        Iterable[
            Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CustomObjects.IInjectionMetaData
        ],
    ]: ...
    @overload
    def LoadAcamlMetadataAsync(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        path: str,
        cancellationToken: System.Threading.CancellationToken,
        createIfMissing: bool = ...,
    ) -> System.Threading.Tasks.Task[
        Iterable[
            Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CustomObjects.IInjectionMetaData
        ]
    ]: ...
    @overload
    def LoadAcamlMetadataAsync(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        path: str,
        version: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo,
        cancellationToken: System.Threading.CancellationToken,
        createIfMissing: bool = ...,
    ) -> System.Threading.Tasks.Task[
        Iterable[
            Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CustomObjects.IInjectionMetaData
        ]
    ]: ...
    @overload
    def LoadAcamlMetadataAsync(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        paths: Iterable[str],
        cancellationToken: System.Threading.CancellationToken,
        createIfMissing: bool = ...,
    ) -> System.Threading.Tasks.Task[
        Dict[
            str,
            Iterable[
                Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CustomObjects.IInjectionMetaData
            ],
        ]
    ]: ...
    @staticmethod
    def UnloadAll() -> None: ...
    @staticmethod
    def Validate(
        acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML,
    ) -> bool: ...
    @staticmethod
    def CreateAcaml(
        description: str,
        userName: str,
        clientName: str,
        appType: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.AgilentAppType,
    ) -> Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML: ...
    def CreateReader(self) -> IAcamlReader: ...
    @staticmethod
    def UnloadAcaml(docId: System.Guid) -> None: ...
    @staticmethod
    def UnloadAcamls(docIds: Iterable[System.Guid]) -> None: ...

class AcamlSignalLoader(IAcamlSignalLoader):  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def CancelSignalPrefetching() -> None: ...
    def ExtractChromatograms(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        docId: System.Guid,
        spectra: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
        signalMetaDataAndParameters: Dict[
            Agilent.OpenLab.Framework.DataAccess.CoreTypes.IExtractionParameters,
            Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
        ],
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.CoreType.IExtractedSignalDataContainer[
            Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData
        ]
    ]: ...
    def LoadInstrumentTrace(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        docId: System.Guid,
        signal: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData: ...
    def LoadReferenceChromatogram(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        docId: System.Guid,
        path: str,
        traceId: str,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData: ...
    def GetSignalInformation(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        docId: System.Guid,
        signal: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISignalInformation: ...
    @overload
    @staticmethod
    def LoadChromatogram(
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        path: str,
    ) -> Sequence[
        Agilent.OpenLab.Framework.DataAccess.CoreType.ISignalDataContainer[
            Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData
        ]
    ]: ...
    @overload
    @staticmethod
    def LoadChromatogram(
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        docId: System.Guid,
        signal: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData: ...
    def ReadGenericAnalyticalResultData(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        genericAnalyticalResultDataInfo: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IGenericAnalyticalResultDataInfo,
    ) -> List[int]: ...
    def ReadGenericAnalyticalResultDataInfo(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        docId: System.Guid,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionMeasDataType,
    ) -> Sequence[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IGenericAnalyticalResultDataInfo
    ]: ...
    def ExtractChromatogram(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        docId: System.Guid,
        spectra: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
        metadataOfSignalToExtract: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
        chromatogramExtractionParameters: Agilent.OpenLab.Framework.DataAccess.CoreTypes.ChromatogramExtractionParameters,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData: ...
    def TriggerSignalPrefetching(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        injectionOrder: Iterable[
            Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CustomObjects.AcamlInjectionId
        ],
        currentIndex: int,
    ) -> None: ...
    def UnloadSignalFromCache(
        self,
        docId: System.Guid,
        signalType: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
    ) -> None: ...
    def ExtractSpectra(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        docId: System.Guid,
        spectra: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
        signalMetaDataAndParameters: Dict[
            Agilent.OpenLab.Framework.DataAccess.CoreTypes.IExtractionParameters,
            Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
        ],
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.CoreType.IExtractedSignalDataContainer[
            Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectrumData
        ]
    ]: ...
    @overload
    @staticmethod
    def LoadSpectra(
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        path: str,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectraData: ...
    @overload
    @staticmethod
    def LoadSpectra(
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        docId: System.Guid,
        signal: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectraData: ...
    def ExtractSpectrum(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        docId: System.Guid,
        spectra: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
        metadataOfSignalToExtract: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
        spectrumExtractionParameters: Agilent.OpenLab.Framework.DataAccess.CoreTypes.SpectrumExtractionParameters,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectrumData: ...

class AcamlSignalLoaderManager:  # Class
    AcamlSignalLoader: IAcamlSignalLoader  # static # readonly

    @staticmethod
    def SetSignalLoader(acamSignalLoader: IAcamlSignalLoader) -> None: ...

class CalibrationCurveReaderWriter:  # Class
    @staticmethod
    def Deserialize(
        serializedCalibrationCurve: str,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICalibrationCurveType: ...
    @staticmethod
    def Serialize(
        calibrationCurve: Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICalibrationCurveType,
    ) -> str: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .ViewModel import (
    IBatchTableViewModel,
    IControlPanelViewModel,
    ITask,
    TaskViewModelBase,
)

# Stubs for namespace: Agilent.MassHunter.Quantitative.Startup.Edit.BatchTable

class BatchTableLayout:  # Class
    def __init__(
        self,
        mode: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TableViewMode,
        singleCompounds: bool,
        displayName: str,
    ) -> None: ...

    DisplayName: str  # readonly
    SingleCompounds: bool  # readonly
    TableViewMode: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TableViewMode
    )  # readonly

class BatchTableView(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class BatchTableViewModel(TaskViewModelBase, IBatchTableViewModel, ITask):  # Class
    def __init__(self, rootModel: IControlPanelViewModel) -> None: ...

    AvailableColumnsProperty: System.Windows.DependencyProperty  # static
    IsEnabledProperty: System.Windows.DependencyProperty  # static
    SelectedDefaultBatchTableLayoutProperty: System.Windows.DependencyProperty  # static
    SelectedTableLayoutProperty: System.Windows.DependencyProperty  # static
    SelectedTableProperty: System.Windows.DependencyProperty  # static
    VisibleColumnsProperty: System.Windows.DependencyProperty  # static

    AddColumnCommand: System.Windows.Input.ICommand  # readonly
    AvailableColumns: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.BatchTable.ColumnItem
    ]
    BatchTableLayouts: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.BatchTable.BatchTableLayout
    ]  # readonly
    Content: System.Windows.UIElement  # readonly
    IsEnabled: bool  # readonly
    MoveDownCommand: System.Windows.Input.ICommand  # readonly
    MoveUpCommand: System.Windows.Input.ICommand  # readonly
    RemoveColumnCommand: System.Windows.Input.ICommand  # readonly
    SelectedDefaultBatchTableLayout: (
        Agilent.MassHunter.Quantitative.Startup.Edit.BatchTable.BatchTableLayout
    )
    SelectedTable: Agilent.MassHunter.Quantitative.Startup.Edit.BatchTable.TableItem
    SelectedTableLayout: (
        Agilent.MassHunter.Quantitative.Startup.Edit.BatchTable.BatchTableLayout
    )
    Tables: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.BatchTable.TableItem
    ]  # readonly
    Title: str  # readonly
    VisibleColumns: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.BatchTable.ColumnItem
    ]

    def MoveDown(self, parameters: Any) -> None: ...
    def ResetToDefault(self) -> None: ...
    def Reload(self) -> None: ...
    def MoveUp(self, parameters: Any) -> None: ...
    def CanMoveDown(self, parameters: Any) -> bool: ...
    def IsDirty(self) -> bool: ...
    def Activate(self) -> None: ...
    def CanMoveUp(self, parameters: Any) -> bool: ...
    def GetTools(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Tools: ...
    def UpdateColumns(self) -> None: ...

class ColumnIsAvailableConverter(System.Windows.Data.IValueConverter):  # Class
    def __init__(self) -> None: ...
    def ConvertBack(
        self,
        value_: Any,
        targetType: System.Type,
        parameter: Any,
        culture: System.Globalization.CultureInfo,
    ) -> Any: ...
    def Convert(
        self,
        value_: Any,
        targetType: System.Type,
        parameter: Any,
        culture: System.Globalization.CultureInfo,
    ) -> Any: ...

class ColumnItem(System.Windows.DependencyObject):  # Class
    def __init__(
        self,
        model: Agilent.MassHunter.Quantitative.Startup.Edit.BatchTable.BatchTableViewModel,
        relation: str,
        column: str,
    ) -> None: ...

    IsSelectedProperty: System.Windows.DependencyProperty  # static
    IsVisibleProperty: System.Windows.DependencyProperty  # static

    Column: str  # readonly
    DisplayName: str  # readonly
    IsSelected: bool
    IsVisible: bool
    Relation: str  # readonly

class TableItem:  # Class
    def __init__(
        self,
        model: Agilent.MassHunter.Quantitative.Startup.Edit.BatchTable.BatchTableViewModel,
        relation: str,
    ) -> None: ...

    DisplayName: str  # readonly
    IsEnabled: bool  # readonly
    Relation: str  # readonly

class ToolHandler(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolHandler
):  # Class
    def __init__(self) -> None: ...
    def Execute(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        uiState: Any,
    ) -> None: ...
    def SetState(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        uiState: Any,
    ) -> None: ...

class VisibleColumnsKey:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        mode: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TableViewMode,
        single: bool,
        relation: str,
    ) -> None: ...

    Relation: str
    SingleMode: bool
    TableViewMode: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TableViewMode

    def GetHashCode(self) -> int: ...
    def Equals(self, obj: Any) -> bool: ...
